@@ -57,7 +57,7 @@ email                : mte@users.sourceforge.net
   #include "../dialogs/ieditscheduledialog.h"
   #include "../widgets/kmymoneyedit.h"
   #define TRY try {
-  #define CATCH } catch (MyMoneyException *e) { 
+  #define CATCH } catch (MyMoneyException *e) {
   #define PASS } catch (MyMoneyException *e) { throw e; }
 #else
   #include "mymoneymoney.h"
@@ -72,11 +72,6 @@ email                : mte@users.sourceforge.net
 #endif // _GNCFILEANON
 
 // init static variables
-// to hold gnucash count data (only used for progress bar)
-int GncObject::m_gncCommodityCount = 0;
-int GncObject::m_gncAccountCount = 0;
-int GncObject::m_gncTransactionCount = 0;
-int GncObject::m_gncScheduleCount = 0;
 double MyMoneyGncReader::m_fileHideFactor = 0.0;
 double GncObject::m_moneyHideFactor;
 
@@ -88,6 +83,7 @@ void MyMoneyGncReader::setOptions () {
     // set users input options
     m_dropSuspectSchedules = dlg.scheduleOption();
     m_investmentOption = dlg.investmentOption();
+    m_decoder = dlg.decodeOption();
     gncdebug = dlg.generalDebugOption();
     xmldebug = dlg.xmlDebugOption();
     bAnonymize = dlg.anonymizeOption();
@@ -111,10 +107,6 @@ void MyMoneyGncReader::setOptions () {
 
 GncObject::GncObject () {
   m_v.setAutoDelete (true);
-  m_gncCommodityCount = 0;
-  m_gncAccountCount = 0;
-  m_gncTransactionCount = 0;
-  m_gncScheduleCount = 0;
 }
 
 // Check that the current element is of a version we are coded for
@@ -184,6 +176,14 @@ bool GncObject::isDataElement (const QString &elName, const QXmlAttributes& elAt
   return (false);
   PASS
 }
+
+// return the variable string, decoded if required
+const QString GncObject::var (int i) const {
+  return (pMain->m_decoder == 0
+      ? *(m_v.at(i))
+      : pMain->m_decoder->toUnicode (*(m_v.at(i))));
+}
+
 void GncObject::adjustHideFactor () {
   m_moneyHideFactor = pMain->m_fileHideFactor * (1.0 + (int)(200.0 * rand()/(RAND_MAX+1.0))) / 100.0;
 }
@@ -382,6 +382,14 @@ void GncKvp::endSubEl(GncObject *subObj) {
   m_dataPtr = 0;
   return ;
 }
+//*********************************GncLot*********************************************
+GncLot::GncLot() {
+  m_subElementListCount = 0;
+  m_dataElementListCount = 0;
+}
+
+GncLot::~GncLot() {}
+
 //*********************************GncCountData***************************************
 GncCountData::GncCountData() {
   m_subElementListCount = 0;
@@ -398,17 +406,23 @@ void GncCountData::initiate (const QString&, const QXmlAttributes& elAttrs) {
 }
 
 void GncCountData::terminate () {
+  int i = m_v.at(0)->toInt();
   if (m_countType == "commodity") {
-    m_gncCommodityCount = m_v.at(0)->toInt(); return ;
+    pMain->setGncCommodityCount(i); return ;
   }
   if (m_countType == "account") {
-    m_gncAccountCount = m_v.at(0)->toInt(); return ;
+    pMain->setGncAccountCount(i); return ;
   }
   if (m_countType == "transaction") {
-    m_gncTransactionCount = m_v.at(0)->toInt(); return ;
+    pMain->setGncTransactionCount(i); return ;
   }
   if (m_countType == "schedxaction") {
-    m_gncScheduleCount = m_v.at(0)->toInt(); return ;
+    pMain->setGncScheduleCount(i); return ;
+  }
+  if (i != 0) {
+    if (m_countType == "budget") pMain->setBudgetsFound(true);
+    else if (m_countType.left(7) == "gnc:Gnc") pMain->setSmallBusinessFound(true);
+    else if (pMain->xmldebug) qDebug ("Unknown count type %s", m_countType.latin1());
   }
   return ;
 }
@@ -485,7 +499,7 @@ void GncPrice::terminate() {
 //************* GncAccount********************************************
 GncAccount::GncAccount () {
   m_subElementListCount = END_Account_SELS;
-  static const QString subEls[] = {"act:commodity", "slot"};
+  static const QString subEls[] = {"act:commodity", "slot", "act:lots"};
   m_subElementList = subEls;
   m_dataElementListCount = END_Account_DELS;
   static const QString dataEls[] = {"act:id", "act:name", "act:description",
@@ -493,7 +507,7 @@ GncAccount::GncAccount () {
   m_dataElementList = dataEls;
   static const unsigned int anonClasses[] = {ASIS, NXTACC, SUPPRESS, ASIS, ASIS};
   m_anonClassList = anonClasses;
-  kvpList.setAutoDelete (true);
+  m_kvpList.setAutoDelete (true);
   for (uint i = 0; i < m_dataElementListCount; i++) m_v.append (new QString (""));
   m_vpCommodity = NULL;
 }
@@ -509,6 +523,9 @@ GncObject *GncAccount::startSubEl() {
   switch (m_state) {
   case CMDTY: next = new GncCmdtySpec; break;
   case KVP: next = new GncKvp; break;
+  case LOTS: next = new GncLot();
+             pMain->setLotsFound(true); // we don't handle lots; just set flag to report
+             break;
   default: throw new MYMONEYEXCEPTION ("GncAccount rcvd invalid m_state");
   }
   return (next);
@@ -519,7 +536,7 @@ void GncAccount::endSubEl(GncObject *subObj) {
   if (pMain->xmldebug) qDebug ("Account end subel");
   switch (m_state) {
   case CMDTY: m_vpCommodity = static_cast<GncCmdtySpec *>(subObj); break;
-  case KVP: kvpList.append (subObj);
+  case KVP: m_kvpList.append (subObj);
   }
   return ;
 }
@@ -930,7 +947,11 @@ MyMoneyGncReader::MyMoneyGncReader() {
   m_messageList.setAutoDelete (true);
   m_templateList.setAutoDelete (true);
 #endif // _GNCFILEANON
+// to hold gnucash count data (only used for progress bar)
+  m_gncCommodityCount = m_gncAccountCount = m_gncTransactionCount = m_gncScheduleCount = 0;
+  m_smallBusinessFound = m_budgetsFound = m_lotsFound = false;
   m_commodityCount = m_priceCount = m_accountCount = m_transactionCount = m_templateCount = m_scheduleCount = 0;
+  m_decoder = 0;
 }
 
 //***************** Destructor *************************
@@ -948,11 +969,11 @@ void MyMoneyGncReader::readFile(QIODevice* pDevice, IMyMoneySerialize* storage)
   setOptions ();
   // get a file anonymization factor from the user
   if (bAnonymize) setFileHideFactor ();
-  m_defaultPayee = createPayee (i18n("Unknown payee"));
+  //m_defaultPayee = createPayee (i18n("Unknown payee"));
 
-  xr = new XmlReader (this);
+  m_xr = new XmlReader (this);
   try {
-    xr->processFile (pDevice);
+    m_xr->processFile (pDevice);
     terminate (); // do all the wind-up things
   } catch (MyMoneyException *e) {
     QMessageBox::critical (0, PACKAGE, i18n("Import failed\n\n") + e->what(),
@@ -960,7 +981,7 @@ void MyMoneyGncReader::readFile(QIODevice* pDevice, IMyMoneySerialize* storage)
     qFatal ("%s", e->what().latin1());
   } // end catch
   signalProgress ( -1, -1); // switch off progress bar
-  delete xr;
+  delete m_xr;
   qDebug ("Exiting gnucash importer");
   return ;
 }
@@ -975,13 +996,13 @@ void MyMoneyGncReader::readFile(QString in, QString out) {
   bAnonymize = true;
   // get a file anonymization factor from the user
   setFileHideFactor ();
-  xr = new XmlReader (this);
+  m_xr = new XmlReader (this);
   try {
-    xr->processFile (&pDevice);
+    m_xr->processFile (&pDevice);
   } catch (MyMoneyException *e) {
     qFatal ("%s", e->latin1());
   } // end catch
-  delete xr;
+  delete m_xr;
   pDevice.close();
   outFile.close();
   return ;
@@ -1016,19 +1037,20 @@ void MyMoneyGncReader::setFileHideFactor () {
       m_fileHideFactor = QInputDialog::getDouble (
         i18n ("Disguise your wealth"),
         i18n ("Each monetary value on your file will be multiplied by a random number between 0.01 and 1.99\n"
-	             "with a different value used for each transaction. In addition, to further disguise the true\n"
-		             "values, you may enter a number between %1 and %2 which will be applied to all values.\n"
-		             "These numbers will not be stored in the file.").arg(MINFILEHIDEF).arg(MAXFILEHIDEF),
-        	(1.0 + (int)(1000.0 * rand() / (RAND_MAX + 1.0))) / 100.0,
+                     "with a different value used for each transaction. In addition, to further disguise the true\n"
+                             "values, you may enter a number between %1 and %2 which will be applied to all values.\n"
+                             "These numbers will not be stored in the file.").arg(MINFILEHIDEF).arg(MAXFILEHIDEF),
+                (1.0 + (int)(1000.0 * rand() / (RAND_MAX + 1.0))) / 100.0,
         MINFILEHIDEF, MAXFILEHIDEF, 2);
     }
 }
 #ifndef _GNCFILEANON
+
 //********************************* convertCommodity *******************************************
 void MyMoneyGncReader::convertCommodity (const GncCommodity *gcm) {
   Q_CHECK_PTR (gcm);
   MyMoneySecurity equ;
-  if (m_commodityCount == 0) signalProgress (0, gcm->gncCommodityCount(), i18n("Loading commodities..."));
+  if (m_commodityCount == 0) signalProgress (0, m_gncCommodityCount, i18n("Loading commodities..."));
   if (!gcm->isCurrency()) { // currencies should not be present here but...
     equ.setName (gcm->name());
     equ.setTradingSymbol (gcm->id());
@@ -1077,7 +1099,7 @@ void MyMoneyGncReader::convertAccount (const GncAccount* gac) {
   TRY
 
   MyMoneyAccount acc;
-  if (m_accountCount == 0) signalProgress (0, gac->gncAccountCount(), i18n("Loading accounts..."));
+  if (m_accountCount == 0) signalProgress (0, m_gncAccountCount, i18n("Loading accounts..."));
   acc.setName(gac->name());
 
   acc.setDescription(gac->desc());
@@ -1093,15 +1115,24 @@ void MyMoneyGncReader::convertAccount (const GncAccount* gac) {
 
   acc.setParentAccountId (gac->parent().utf8());
   // now determine the account type and its parent id
-  if (QString("BANK") == gac->type()) {
+  /* This list taken from
+# Feb 2006: A RELAX NG Compact schema for gnucash "v2" XML files.
+# Copyright (C) 2006 Joshua Sled <jsled@asynchronous.org>
+"NO_TYPE" "BANK" "CASH" "CREDIT" "ASSET" "LIABILITY" "STOCK" "MUTUAL" "CURRENCY"
+"INCOME" "EXPENSE" "EQUITY" "RECEIVABLE" "PAYABLE" "CHECKING" "SAVINGS" "MONEYMRKT" "CREDITLINE" 
+  Some don't seem to be used in practice. Not sure what CREDITLINE s/be converted as.
+  */
+  if ("BANK" == gac->type() || "CHECKING" == gac->type()) {
     acc.setAccountType(MyMoneyAccount::Checkings);
-  } else if (QString("ASSET") == gac->type()) {
+  } else if ("SAVINGS" == gac->type()) {
+    acc.setAccountType(MyMoneyAccount::Savings);
+  } else if ("ASSET" == gac->type()) {
     acc.setAccountType(MyMoneyAccount::Asset);
-  } else if (QString("CASH") == gac->type()) {
+  } else if ("CASH" == gac->type()) {
     acc.setAccountType(MyMoneyAccount::Cash);
-  } else if (QString("CURRENCY") == gac->type()) {
+  } else if ("CURRENCY" == gac->type()) {
     acc.setAccountType(MyMoneyAccount::Cash);
-  } else if (QString("STOCK") == gac->type() || QString("MUTUAL") == gac->type() ) {
+  } else if ("STOCK" == gac->type() || "MUTUAL" == gac->type() ) {
     // gnucash allows a 'broker' account to be denominated as type STOCK, but with
     // a currency balance. We do not need to create a stock account for this
     // actually, the latest version of gnc (1.8.8) doesn't seem to allow you to do
@@ -1111,20 +1142,22 @@ void MyMoneyGncReader::convertAccount (const GncAccount* gac) {
     } else {
       acc.setAccountType(MyMoneyAccount::Stock);
     }
-  } else if (QString("EQUITY") == gac->type()) {
+  } else if ("EQUITY" == gac->type()) {
     acc.setAccountType(MyMoneyAccount::Equity);
-  } else if (QString("LIABILITY") == gac->type()) {
+  } else if ("LIABILITY" == gac->type()) {
     acc.setAccountType(MyMoneyAccount::Liability);
-  } else if (QString("CREDIT") == gac->type()) {
+  } else if ("CREDIT" == gac->type()) {
     acc.setAccountType(MyMoneyAccount::CreditCard);
-  } else if (QString("INCOME") == gac->type()) {
+  } else if ("INCOME" == gac->type()) {
     acc.setAccountType(MyMoneyAccount::Income);
-  } else if (QString("EXPENSE") == gac->type()) {
+  } else if ("EXPENSE" == gac->type()) {
     acc.setAccountType(MyMoneyAccount::Expense);
-  } else if (QString("RECEIVABLE") == gac->type()) {
+  } else if ("RECEIVABLE" == gac->type()) {
     acc.setAccountType(MyMoneyAccount::Asset);
-  } else if (QString("PAYABLE") == gac->type()) {
+  } else if ("PAYABLE" == gac->type()) {
     acc.setAccountType(MyMoneyAccount::Liability);
+  } else if ("MONEYMRKT" == gac->type()) {
+    acc.setAccountType(MyMoneyAccount::MoneyMarket);
   } else { // we have here an account type we can't currently handle
     QString em =
         i18n("Current importer does not recognize GnuCash account type %1").arg(gac->type());
@@ -1151,7 +1184,7 @@ void MyMoneyGncReader::convertAccount (const GncAccount* gac) {
     if (gncdebug) qDebug ("Acct equity search, key = %s, found id = %s",
                             gac->commodity()->id().latin1(), e.id().data());
     acc.setCurrencyId (e.id()); // actually, the security id
-    if (QString("MUTUAL") == gac->type()) {
+    if ("MUTUAL" == gac->type()) {
       e.setSecurityType (MyMoneySecurity::SECURITY_MUTUALFUND);
       if (gncdebug) qDebug ("Setting %s to mutual", e.name().latin1());
       m_storage->modifySecurity (e);
@@ -1160,7 +1193,7 @@ void MyMoneyGncReader::convertAccount (const GncAccount* gac) {
     // NB: In gnc, this selection is per account, in KMM, per security
     // This is unlikely to cause problems in practice. If it does,
     // we probably need to introduce a 'pricing basis' in the account class
-    QPtrListIterator<GncObject> kvpi (gac->kvpList);
+    QPtrListIterator<GncObject> kvpi (gac->m_kvpList);
     GncKvp *k;
     while ((k = static_cast<GncKvp *>(kvpi.current())) != 0) {
       if (k->key().contains("price-source") && k->type() == "string") {
@@ -1171,6 +1204,19 @@ void MyMoneyGncReader::convertAccount (const GncAccount* gac) {
       }
     }
   }
+  
+  // check for tax-related status
+  QPtrListIterator<GncObject> kvpi (gac->m_kvpList);
+  GncKvp *k;
+  while ((k = static_cast<GncKvp *>(kvpi.current())) != 0) {
+    if (k->key().contains("tax-related") && k->type() == "integer" && k->value() == "1") {
+      acc.setValue ("Tax", "Yes");
+      break;
+    } else {
+      ++kvpi;
+    }
+  }
+
   // all the details from the file about the account should be known by now.
   // calling addAccount will automatically fill in the account ID.
   m_storage->addAccount(acc);
@@ -1179,6 +1225,7 @@ void MyMoneyGncReader::convertAccount (const GncAccount* gac) {
   if (gncdebug) qDebug("Gnucash account %s has id of %s, type of %s, parent is %s",
                          gac->id().latin1(), acc.id().data(),
                          KMyMoneyUtils::accountTypeToString(acc.accountType()).latin1(), acc.parentAccountId().data());
+
   signalProgress (++m_accountCount, 0);
   return ;
   PASS
@@ -1191,10 +1238,10 @@ void MyMoneyGncReader::convertTransaction (const GncTransaction *gtx) {
   MyMoneySplit split;
   unsigned int i;
 
-  if (m_transactionCount == 0) signalProgress (0, gtx->gncTransactionCount(), i18n("Loading transactions..."));
+  if (m_transactionCount == 0) signalProgress (0, m_gncTransactionCount, i18n("Loading transactions..."));
   // initialize class variables related to transactions
   m_txCommodity = "";
-  m_txPayeeId = m_defaultPayee;
+  m_txPayeeId = "";
   m_potentialTransfer = true;
   m_splitList.clear(); m_liabilitySplitList.clear(); m_otherSplitList.clear();
   // payee, dates, commodity
@@ -1274,7 +1321,7 @@ void MyMoneyGncReader::convertSplit (const GncSplit *gsp) {
   split.setNumber (m_txChequeNo);
   // value and quantity
   MyMoneyMoney splitValue (convBadValue (gsp->value()));
-  if (gsp->value() == QString("-1/0")) { // treat gnc invalid value as zero
+  if (gsp->value() == "-1/0") { // treat gnc invalid value as zero
    // it's not quite a consistency check, but easier to treat it as such
    postMessage ("CC", 4, splitAccount.name().latin1(), m_txDatePosted.toString(Qt::ISODate).latin1());
   }
@@ -1370,12 +1417,16 @@ MyMoneyTransaction MyMoneyGncReader::convertTemplateTransaction (const QString s
 
   // initialize class variables related to transactions
   m_txCommodity = "";
-  m_txPayeeId = m_defaultPayee;
+  m_txPayeeId = "";
   m_potentialTransfer = true;
   m_splitList.clear(); m_liabilitySplitList.clear(); m_otherSplitList.clear();
 
   // payee, dates, commodity
-  if (!gtx->desc().isEmpty()) m_txPayeeId = createPayee (gtx->desc());
+  if (!gtx->desc().isEmpty()) {
+    m_txPayeeId = createPayee (gtx->desc());
+  } else {
+    m_txPayeeId = createPayee (i18n("Unknown payee")); // schedules require a payee tho normal tx's don't. not sure why...
+  }
   tx.setEntryDate(gtx->dateEntered());
   tx.setPostDate(gtx->datePosted());
   m_txDatePosted = tx.postDate();
@@ -1387,7 +1438,7 @@ MyMoneyTransaction MyMoneyGncReader::convertTemplateTransaction (const QString s
   }
   // determine the action type for the splits and link them to the template tx
   /*QCString negativeActionType, positiveActionType;
-  if (!m_splitList.isEmpty()) { // if there are asset splits 
+  if (!m_splitList.isEmpty()) { // if there are asset splits
     positiveActionType = MyMoneySplit::ActionDeposit;
     negativeActionType = MyMoneySplit::ActionWithdrawal;
   } else { // if there are liability splits
@@ -1566,7 +1617,7 @@ void MyMoneyGncReader::convertSchedule (const GncSchedule *gsc) {
   QDate today = QDate::currentDate();
   int numOccurs, remOccurs;
 
-  if (m_scheduleCount == 0) signalProgress (0, gsc->gncScheduleCount(), i18n("Loading schedules..."));
+  if (m_scheduleCount == 0) signalProgress (0, m_gncScheduleCount, i18n("Loading schedules..."));
   // schedule name
   sc.setName(gsc->name());
   // find the transaction template as stored earlier
@@ -1592,7 +1643,11 @@ void MyMoneyGncReader::convertSchedule (const GncSchedule *gsc) {
     MyMoneySchedule::occurenceE occ; // equivalent occurence code
     MyMoneySchedule::weekendOptionE wo;
   };
+  /* other intervals supported by gnc according to Josh Sled's schema (see above)
+   "none" "semi_monthly"
+   */
   static convIntvl vi [] = {
+                             {"once", 'o', 1, MyMoneySchedule::OCCUR_ONCE, MyMoneySchedule::MoveNothing },
                              {"daily" , 'd', 1, MyMoneySchedule::OCCUR_DAILY, MyMoneySchedule::MoveNothing },
                              //{"daily_mf", 'd', 1, MyMoneySchedule::OCCUR_DAILY, MyMoneySchedule::MoveMonday }, doesn't work, need new freq in kmm
                              {"weekly", 'w', 1, MyMoneySchedule::OCCUR_WEEKLY, MyMoneySchedule::MoveNothing },
@@ -1653,7 +1708,7 @@ void MyMoneyGncReader::convertSchedule (const GncSchedule *gsc) {
   // payment type, options
   sc.setPaymentType((MyMoneySchedule::paymentTypeE)MyMoneySchedule::STYPE_OTHER);
   sc.setFixed (!m_suspectSchedule); // if any probs were found, set it as variable so user will always be prompted
-  sc.setAutoEnter (gsc->autoCreate() == QString ("y"));
+  sc.setAutoEnter (gsc->autoCreate() == "y");
   // type
   QCString actionType = tx.splits().first().action();
   if (actionType == MyMoneySplit::ActionDeposit) {
@@ -1752,7 +1807,7 @@ void MyMoneyGncReader::terminate () {
       mainCurrency = it.key();
       }
   }
-  
+
   if (mainCurrency != "") {
     /* fix for qt3.3.4?. According to Qt docs, this should return the enum id of the button pressed, and
        indeed it used to do so. However now it seems to return the index of the button. In this case it doesn't matter,
@@ -1807,7 +1862,9 @@ void MyMoneyGncReader::terminate () {
                     QMessageBox::NoButton);
     switch (mb.exec()) {
     case QMessageBox::Yes:
-        KEditScheduleDialog *s = new  KEditScheduleDialog (sc.transaction().splits()[0].action(), sc, 0, "");;
+        KEditScheduleDialog *s = new  KEditScheduleDialog (sc.transaction().splits()[0].action(), sc, 0, "");
+        // FIXME: connect newCategory to something useful, so that we
+        // can create categories from within the dialog
         if (s->exec())
           m_storage->modifySchedule (s->schedule());
         delete s;
@@ -1844,6 +1901,15 @@ const QString MyMoneyGncReader::buildReportSection (const QString source) {
       s.append (QString::number(m_scCount) + i18n(" possible schedule problems were noted\n"));
       more = true;
     }
+    QString unsupported ("");
+    QString lineSep ("\n  - ");
+    if (m_smallBusinessFound) unsupported.append(lineSep + i18n("Small Business Features (Customers, Invoices, etc.)"));
+    if (m_budgetsFound) unsupported.append(lineSep + i18n("Budgets"));
+    if (m_lotsFound) unsupported.append(lineSep + i18n("Lots"));
+    if (!unsupported.isEmpty()) {
+      unsupported.prepend(i18n("The following features found in your file are not currently supported:"));
+      s.append(unsupported);
+    }
     if (more) s.append (i18n("\n\nPress More for further information"));
   } else { // we need to retrieve the posted messages for this source
     unsigned int i, j;
@@ -1930,6 +1996,8 @@ QDate MyMoneyGncReader::incrDate (QDate lastDate, unsigned char interval, unsign
     return (lastDate.addMonths(intervalCount));
   case 'y':
     return (lastDate.addYears(intervalCount));
+  case 'o': // once-only
+    return (lastDate);
   }
   throw new MYMONEYEXCEPTION (i18n("Internal error - invalid interval char in incrDate"));
   QDate r = QDate(); return (r); // to keep compiler happy
