@@ -152,6 +152,7 @@ class QIODevice;
 #include <qptrstack.h>
 #include <qxml.h>
 #include <qdatetime.h>
+#include <qtextcodec.h>
 
 // ----------------------------------------------------------------------------
 // Project Includes
@@ -208,11 +209,6 @@ protected:
   static void checkVersion (const QString&, const QXmlAttributes&);
   // get name of element processed by 'this'
   const QString getElName () const { return (m_elementName);};
-  // return gnucash counts (not always accurate!)
-  int gncCommodityCount() const { return (m_gncCommodityCount);};
-  int gncAccountCount () const { return (m_gncAccountCount);};
-  int gncTransactionCount () const { return (m_gncTransactionCount);};
-  int gncScheduleCount () const { return (m_gncScheduleCount);};
   // pass 'main' pointer to object
   void setPm (MyMoneyGncReader *pM) {pMain = pM;};
   // debug only
@@ -223,7 +219,7 @@ protected:
   // called by isDataElement to set variable pointer
   virtual void dataEl(const QXmlAttributes&) {m_dataPtr = m_v.at(m_state); m_anonClass = m_anonClassList[m_state];};
   // return gnucash data string variable pointer
-  virtual const QString var (int i) const { return (*(m_v.at(i)));};
+  virtual const QString var (int i) const;
   // anonymize data
   virtual QString hide (QString, unsigned int);
   
@@ -245,11 +241,6 @@ protected:
   enum anonActions {ASIS, SUPPRESS, NXTACC, NXTEQU, NXTPAY, NXTSCHD, MAYBEQ, MONEY1, MONEY2}; // anonymize actions - see hide()
   unsigned int m_anonClass; // class of current data item for anonymizer
   static double m_moneyHideFactor; // a per-transaction factor
-  
-  static int m_gncCommodityCount; // to hold count data from gnc file
-  static int m_gncAccountCount;
-  static int m_gncTransactionCount;
-  static int m_gncScheduleCount;
 };
 
 // *****************************************************************************
@@ -334,6 +325,16 @@ private:
   mutable QPtrList<GncObject> m_kvpList;
   QString m_kvpType;  // type is an XML attribute
 };
+// ************* GncLot********************************************
+// KMM doesn't have support for lots as yet
+class GncLot : public GncObject {
+  public:
+    GncLot ();
+    ~GncLot();
+  protected:
+    friend class MyMoneyGncReader;
+  private:
+};
 
 /** Following are the main objects within the gnucash file, which correspond largely one-for-one
     with similar objects in the kmymoney structure, apart from schedules which gnc splits between
@@ -406,14 +407,14 @@ protected:
   const QString parent () const { return (var(PARENT));};
 private:
   // subsidiary objects/elements
-  enum AccountSubEls {CMDTY, KVP, END_Account_SELS };
+  enum AccountSubEls {CMDTY, KVP, LOTS, END_Account_SELS };
   virtual GncObject *startSubEl();
   virtual void endSubEl(GncObject *);
   virtual void terminate();
   // data elements
   enum AccountDataEls {ID, NAME, DESC, TYPE, PARENT, END_Account_DELS };
   GncCmdtySpec *m_vpCommodity;
-  QPtrList<GncObject> kvpList;
+  QPtrList<GncObject> m_kvpList;
 };
 // ************* GncSplit********************************************
 class GncSplit : public GncObject {
@@ -651,13 +652,15 @@ public:
 #else
   void readFile (QString, QString);
 #endif // _GNCFILEANON
-
+  QTextCodec *m_decoder;
 protected:
   friend class GncObject; // pity we can't just say GncObject. And compiler doesn't like multiple friends on one line...
   friend class GncFile; // there must be a better way...
   friend class GncDate;
   friend class GncCmdtySpec;
   friend class GncKvp;
+  friend class GncLot;
+  friend class GncCountData;
   friend class GncCommodity;
   friend class GncPrice;
   friend class GncAccount;
@@ -718,6 +721,14 @@ protected:
        N.B. :- option 2 doesn't really work quite as desired at present
   */
   unsigned int m_investmentOption;
+    // set gnucash counts (not always accurate!)
+  void setGncCommodityCount(int i) { m_gncCommodityCount = i;};
+  void setGncAccountCount (int i) { m_gncAccountCount = i;};
+  void setGncTransactionCount (int i) { m_gncTransactionCount = i;};
+  void setGncScheduleCount (int i) { m_gncScheduleCount = i;};
+  void setSmallBusinessFound (bool b) { m_smallBusinessFound = b;};
+  void setBudgetsFound (bool b) { m_budgetsFound = b;};
+  void setLotsFound (bool b) { m_lotsFound = b;};
   /*          Debug Options
     If you don't know what these are, best leave them alone.
        gncdebug - produce general debug messages
@@ -748,9 +759,20 @@ private:
 #else
   QTextStream oStream;
 #endif // _GNCFILEANON
-  XmlReader *xr;
+  XmlReader *m_xr;
   /** to hold the callback pointer for the progress bar */
   void (*m_progressCallback)(int, int, const QString&);
+  // counters holding count data from the Gnc 'count-data' section
+  int m_gncCommodityCount;
+  int m_gncAccountCount;
+  int m_gncTransactionCount;
+  int m_gncScheduleCount;
+  
+  // flags indicating detection of features not (yet?) supported
+  bool m_smallBusinessFound;
+  bool m_budgetsFound;
+  bool m_lotsFound;
+  
   /** counters for reporting */
   int m_commodityCount;
   int m_priceCount;
@@ -778,7 +800,6 @@ private:
   /**
     * Temporary storage areas for transaction processing
     */
-  QString m_defaultPayee; // kmm is unhappy without a payee though gnc doesn't necessarily have one
   QCString m_txCommodity; // save commodity for current transaction
   QString m_txPayeeId;    // gnc has payee at tx level, we need it at split level
   QDate m_txDatePosted;   // ditto for post date
