@@ -56,6 +56,8 @@ bool WebPriceQuote::launch( const QString& _symbol, const QString& _id, const QS
   m_symbol = _symbol;
   m_id = _id;
 
+//   emit status(QString("(Debug) symbol=%1 id=%2...").arg(_symbol,_id));
+  
   // if we're running normally, with a UI, we can just get these the normal way,
   // from the config file
   if ( kapp )
@@ -258,8 +260,14 @@ void WebPriceQuote::slotParseQuote(const QString& _quotedata)
     else
     {
       emit error(i18n("Unable to update price for %1").arg(m_symbol));
+      emit failed( m_id, m_symbol );
     }
   }
+  else
+  {
+    emit error(i18n("Unable to update price for %1").arg(m_symbol));
+    emit failed( m_id, m_symbol );
+  }
 }
 
 QMap<QString,WebPriceQuoteSource> WebPriceQuote::defaultQuoteSources(void)
