@@ -248,23 +248,18 @@ void KEditScheduleDialog::reloadFromFile(void)
   for (int i = 0; occurMasks[i] != END_OCCURS; i++) m_kcomboFreq->insertItem (KMyMoneyUtils::occurenceToString (occurMasks[i]));
   m_accountCombo->blockSignals(true);
   m_kcomboTo->blockSignals(true);
-  if (m_actionType == MyMoneySplit::ActionTransfer
-  ||  m_actionType == MyMoneySplit::ActionWithdrawal
-  ||  m_actionType == MyMoneySplit::ActionAmortization
-      )
-  {
-    m_accountCombo->loadList
-        ((KMyMoneyUtils::categoryTypeE)(KMyMoneyUtils::asset | KMyMoneyUtils::liability));
-  }
-
-  if (m_actionType == MyMoneySplit::ActionDeposit ||
-      m_actionType == MyMoneySplit::ActionTransfer)
-  {
-    m_kcomboTo->loadList
-        ((KMyMoneyUtils::categoryTypeE)(KMyMoneyUtils::asset | KMyMoneyUtils::liability));
-  }
+  m_category->blockSignals(true);
+  m_accountCombo->loadList(
+    (KMyMoneyUtils::categoryTypeE)(KMyMoneyUtils::asset | KMyMoneyUtils::liability));
+  m_kcomboTo->loadList(
+    (KMyMoneyUtils::categoryTypeE)(KMyMoneyUtils::asset | KMyMoneyUtils::liability));
+  QValueList<int> categories;
+  categories << MyMoneyAccount::Income;
+  categories << MyMoneyAccount::Expense;
+  m_category->selector()->loadList(categories);
   m_accountCombo->blockSignals(false);
   m_kcomboTo->blockSignals(false);
+  m_category->blockSignals(false);
 
   // Fire off the activated signals.
   if (m_schedule.name().isEmpty() && m_transaction.splitCount() == 0)
@@ -315,6 +310,11 @@ void KEditScheduleDialog::slotSplitClicked()
     isValidAmount = true;
   }
 
+  if(theAccountId().isEmpty()) {
+    KMessageBox::information(this, i18n("Please specify the account first before you assign splits."));
+    return;
+  }
+
   try
   {
     MyMoneySplit split1;
@@ -365,32 +365,37 @@ void KEditScheduleDialog::slotSplitClicked()
 
       MyMoneySplit s;
       QString category;
+      MyMoneyMoney amount;
 
       disconnect(m_category, SIGNAL(signalFocusIn()), this, SLOT(slotSplitClicked()));
       switch(m_transaction.splitCount())
       {
         case 2:
-          s = m_transaction.splits()[0];
-          category = MyMoneyFile::instance()->accountToCategory(s.accountId());
+          s = m_transaction.splits()[1];
+          if(!s.accountId().isEmpty()) {
+            category = MyMoneyFile::instance()->accountToCategory(s.accountId());
+            amount = m_transaction.splits()[0].value().abs();
+            m_kmoneyeditAmount->setValue(amount);
+          }
           break;
+
         case 1:
           category = QString();
           m_transaction.removeSplits();
           break;
+
         case 0:
           break;
+
         default:
           category = i18n("Split Transaction");
           connect(m_category, SIGNAL(signalFocusIn()), this, SLOT(slotSplitClicked()));
+          amount = m_transaction.splits()[0].value().abs();
+          m_kmoneyeditAmount->setValue(amount);
           break;
       }
+      m_category->loadText(category);
 
-      m_category->setText(category);
-
-      MyMoneySplit split = m_transaction.splits()[0];
-      MyMoneyMoney amount(split.value());
-      amount = amount.abs();
-      m_kmoneyeditAmount->setText(amount.formatMoney());
     }
 
     delete dlg;
@@ -440,6 +445,18 @@ void KEditScheduleDialog::okClicked()
     m_scheduleName->setFocus();
     return;
   }
+  
+  if(m_accountCombo->isEnabled() && m_accountCombo->selectedAccounts().count() == 0) {
+    KMessageBox::information(this, i18n("Please fill in the From account field."));
+    m_accountCombo->setFocus();
+    return;
+  }
+  
+  if(m_kcomboTo->isEnabled() && m_kcomboTo->selectedAccounts().count() == 0) {
+    KMessageBox::information(this, i18n("Please fill in the To account field."));
+    m_kcomboTo->setFocus();
+    return;
+  }
 
   if (m_kcomboPayTo->text().isEmpty())
   {
@@ -821,13 +838,17 @@ void KEditScheduleDialog::slotAmountChanged(const QString&)
         val = -val;
       }
 
+      // FIXME settings shares == value does not support multiple currencies
+      //       we need to fix this
       s.setValue(val);
+      s.setShares(val);
       m_transaction.modifySplit(s);
 
       if(m_transaction.splitCount() == 2)
       {
         MyMoneySplit split = m_transaction.splits()[1];
         split.setValue(-s.value());
+        split.setShares(split.value());
         m_transaction.modifySplit(split);
       }
       else if (count >= 3)
