@@ -38,7 +38,7 @@
 #include "../widgets/kmymoneyedit.h"
 #include "../mymoney/mymoneyaccount.h"
 #include "../widgets/kmymoneydateinput.h"
-#include "kendingbalancedlgdecl.h"
+#include "../dialogs/kendingbalancedlgdecl.h"
 
 /**
   * This dialog is wizard based and used to enter additional
@@ -53,21 +53,24 @@ public:
   KEndingBalanceDlg(const MyMoneyAccount& account, QWidget *parent=0, const char *name=0);
   ~KEndingBalanceDlg();
 
-  const MyMoneyMoney endingBalance(void) const { return m_endingBalance->getMoneyValue(); };
-  const MyMoneyMoney previousBalance(void) const { return m_previousBalance->getMoneyValue(); };
+  const MyMoneyMoney endingBalance(void) const;
+  const MyMoneyMoney previousBalance(void) const;
   const QDate statementDate(void) const { return m_statementDate->getQDate(); };
 
   const MyMoneyTransaction interestTransaction(void) const;
   const MyMoneyTransaction chargeTransaction(void) const;
-  
+
 protected:
   const MyMoneyTransaction createTransaction(const int sign, kMyMoneyEdit *amountEdit, kMyMoneyCategory *categoryEdit) const;
-  
+  const MyMoneyMoney adjustedReturnValue(const MyMoneyMoney& v) const;
+
 protected slots:
   void slotCheckPageFinished(void);
+  void help(void);
 
 private:
   MyMoneyAccount m_account;
+  QMap<QWidget*, QString>         m_helpAnchor;
 };
 
 /**
@@ -87,33 +90,35 @@ public:
     * has been created. If not, an empty transaction will be returned.
     */
   const MyMoneyTransaction adjustmentTransaction(void) const;
-  
+
   /**
     * This method returns the starting date of the statement as provided
     * by the user. The value returned is only valid if the dialog returned
     * with QDialog::accept.
     */
   const QDate startDate(void) const { return m_startDateEdit->getQDate(); };
-  
+
   /**
     * This method returns the ending date of the statement as provided
     * by the user. The value returned is only valid if the dialog returned
     * with QDialog::accept.
     */
   const QDate endDate(void) const { return m_endDateEdit->getQDate(); };
-  
+
 protected:
   const MyMoneyMoney totalInterest(const QDate& start, const QDate& end) const;
   const MyMoneyMoney totalAmortization(const QDate& start, const QDate& end) const;
 
 public slots:
   void next();
-  
+
 protected slots:
   void slotCheckPageFinished(void);
+  void help(void);
 
 private:
   MyMoneyAccountLoan m_account;
+  QMap<QWidget*, QString>         m_helpAnchor;
 };
 
 #endif
