@@ -157,7 +157,7 @@ void KEnterScheduleDialog::initWidgets()
               break;
 
             default:
-              qFatal("invalid account type in %s:%d", __FILE__, __LINE__);
+              qFatal("invalid account type %d for account %s in %s:%d", acc.accountType(), acc.name().data(), __FILE__, __LINE__);
               break;
           }
           break;
