@@ -21,18 +21,15 @@
 #include <qradiobutton.h>
 #include <qcheckbox.h>
 #include <qtimer.h>
+#include <qtabwidget.h>
 
 // ----------------------------------------------------------------------------
 // KDE Includes
 
+#include <kapplication.h>
 #include <kglobal.h>
 #include <klocale.h>
-#if QT_VERSION > 300
 #include <kstandarddirs.h>
-#else
-#include <kstddirs.h>
-#endif
-
 #include <kpushbutton.h>
 #include <klineedit.h>
 #include <klistview.h>
@@ -61,6 +58,7 @@ KFindTransactionDlg::KFindTransactionDlg(QWidget *parent, const char *name)
   // version (with the transaction register) will also fit on the screen
   // by moving the dialog by (-45,-45).
   m_register->setParent(this);
+  m_register->installEventFilter(this);
   m_registerFrame->hide();
   KFindTransactionDlgDecl::update();
   resize(minimumSizeHint());
@@ -74,6 +72,15 @@ KFindTransactionDlg::KFindTransactionDlg(QWidget *parent, const char *name)
   setupPayeesPage();
   setupDetailsPage();
 
+  // We don't need to add the default into the list (see ::slotShowHelp() why)
+  // m_helpAnchor[m_textTab] = QString("details.search");
+  m_helpAnchor[m_accountTab] = QString("details.search.account");
+  m_helpAnchor[m_dateTab] = QString("details.search.date");
+  m_helpAnchor[m_amountTab] = QString("details.search.amount");
+  m_helpAnchor[m_categoryTab] = QString("details.search.category");
+  m_helpAnchor[m_payeeTab] = QString("details.search.payee");
+  m_helpAnchor[m_detailsTab] = QString("details.search.details");
+
   KIconLoader* il = KGlobal::iconLoader();
   KGuiItem resetButtonItem( i18n( "&Reset" ),
                     QIconSet(il->loadIcon("undo", KIcon::Small, KIcon::SizeSmall)),
@@ -93,6 +100,12 @@ KFindTransactionDlg::KFindTransactionDlg(QWidget *parent, const char *name)
                     i18n("Takes the current criteria and searches for matching transactions."));
   m_searchButton->setGuiItem(searchButtonItem);
 
+  KGuiItem helpButtonItem (i18n("&Help"),
+                    QIconSet(il->loadIcon("help", KIcon::Small, KIcon::SizeSmall)),
+                    i18n("Open online help"),
+                    i18n("Opens the online help and shows detailed information about transaction searching."));
+  m_helpButton->setGuiItem(helpButtonItem);
+
   // readConfig();
   slotUpdateSelections();
 
@@ -107,19 +120,17 @@ KFindTransactionDlg::KFindTransactionDlg(QWidget *parent, const char *name)
 
   connect(m_closeButton, SIGNAL(clicked()), this, SLOT(deleteLater()));
 
+  connect(m_helpButton, SIGNAL(clicked()), this, SLOT(slotShowHelp()));
+
   connect(m_textEdit, SIGNAL(textChanged(const QString&)), this, SLOT(slotUpdateSelections()));
 
   connect(m_register, SIGNAL(clicked(int, int, int, const QPoint&)), this, SLOT(slotRegisterClicked(int, int, int, const QPoint&)));
   connect(m_register, SIGNAL(doubleClicked(int, int, int, const QPoint&)), this, SLOT(slotRegisterDoubleClicked(int, int, int, const QPoint&)));
 
-  connect(m_register, SIGNAL(signalEnter()), this, SLOT(slotSelectTransaction()));
   connect(m_register, SIGNAL(signalNextTransaction()), this, SLOT(slotNextTransaction()));
   connect(m_register, SIGNAL(signalPreviousTransaction()), this, SLOT(slotPreviousTransaction()));
   connect(m_register, SIGNAL(signalSelectTransaction(const QCString&)), this, SLOT(slotSelectTransaction(const QCString&)));
 
-  // FIXME: Once we have the online help going, we can show the help button
-  m_helpButton->hide();
-
   m_textEdit->setFocus();
 
   // make sure, we get a note when the engine changes state
@@ -152,6 +163,8 @@ void KFindTransactionDlg::slotReset(void)
 
   m_typeBox->setCurrentItem(MyMoneyTransactionFilter::allTypes);
   m_stateBox->setCurrentItem(MyMoneyTransactionFilter::allStates);
+  m_validityBox->setCurrentItem(MyMoneyTransactionFilter::anyValidity);
+
   m_nrEdit->setEnabled(true);
   m_nrFromEdit->setEnabled(false);
   m_nrToEdit->setEnabled(false);
@@ -233,6 +246,7 @@ void KFindTransactionDlg::slotUpdateSelections(void)
   // Details tab
   if(m_typeBox->currentItem() != 0
   || m_stateBox->currentItem() != 0
+  || m_validityBox->currentItem() != 0
   || (m_nrButton->isChecked() && m_nrEdit->text().length() != 0)
   || (m_nrRangeButton->isChecked()
      && (m_nrFromEdit->text().length() != 0 || m_nrToEdit->text().length() != 0))) {
@@ -303,6 +317,21 @@ void KFindTransactionDlg::selectAllItems(QListView* view, const bool state)
   slotUpdateSelections();
 }
 
+void KFindTransactionDlg::selectItems(QListView* view, const QCStringList& list, const bool state)
+{
+  QListViewItem* it_v;
+
+  for(it_v = view->firstChild(); it_v != 0; it_v = it_v->nextSibling()) {
+    kMyMoneyCheckListItem* it_c = static_cast<kMyMoneyCheckListItem*>(it_v);
+    if(it_c->type() == QCheckListItem::CheckBox && list.contains(it_c->id())) {
+      it_c->setOn(state);
+    }
+    selectSubItems(it_v, list, state);
+  }
+
+  slotUpdateSelections();
+}
+
 void KFindTransactionDlg::setupCategoriesPage(void)
 {
   m_categoriesView->setSelectionMode(QListView::Multi);
@@ -321,48 +350,37 @@ void KFindTransactionDlg::selectAllSubItems(QListViewItem* item, const bool stat
   }
 }
 
+void KFindTransactionDlg::selectSubItems(QListViewItem* item, const QCStringList& list, const bool state)
+{
+  QListViewItem* it_v;
+
+  for(it_v = item->firstChild(); it_v != 0; it_v = it_v->nextSibling()) {
+    kMyMoneyCheckListItem* it_c = static_cast<kMyMoneyCheckListItem*>(it_v);
+    if(list.contains(it_c->id()))
+      it_c->setOn(state);
+    selectSubItems(it_v, list, state);
+  }
+}
+
 void KFindTransactionDlg::setupDatePage(void)
 {
-  int yr, mon, day;
-  yr = QDate::currentDate().year();
-  mon = QDate::currentDate().month();
-  day = QDate::currentDate().day();
-
-  m_startDates[allDates] = QDate();
-  m_startDates[untilToday] = QDate();
-  m_startDates[currentMonth] = QDate(yr,mon,1);
-  m_startDates[currentYear] = QDate(yr,1,1);
-  m_startDates[monthToDate] = QDate(yr,mon,1);
-  m_startDates[yearToDate] = QDate(yr,1,1);
-  m_startDates[lastMonth] = QDate(yr,mon,1).addMonths(-1);
-  m_startDates[lastYear] = QDate(yr,1,1).addYears(-1);
-  m_startDates[last30Days] = QDate::currentDate().addDays(-30);
-  m_startDates[last3Months] = QDate::currentDate().addMonths(-3);
-  m_startDates[last6Months] = QDate::currentDate().addMonths(-6);
-  m_startDates[last12Months] = QDate::currentDate().addMonths(-12);
-  m_startDates[next30Days] = QDate::currentDate();
-  m_startDates[next3Months] = QDate::currentDate();
-  m_startDates[next6Months] = QDate::currentDate();
-  m_startDates[next12Months] = QDate::currentDate();
-  m_startDates[userDefined] = QDate();
-
-  m_endDates[allDates] = QDate();
-  m_endDates[untilToday] = QDate::currentDate();
-  m_endDates[currentMonth] = QDate(yr,mon,1).addMonths(1).addDays(-1);
-  m_endDates[currentYear] = QDate(yr,12,31);
-  m_endDates[monthToDate] = QDate::currentDate();
-  m_endDates[yearToDate] = QDate::currentDate();
-  m_endDates[lastMonth] = QDate(yr,mon,1).addDays(-1);
-  m_endDates[lastYear] = QDate(yr,12,31).addYears(-1);
-  m_endDates[last30Days] = QDate::currentDate();
-  m_endDates[last3Months] = QDate::currentDate();
-  m_endDates[last6Months] = QDate::currentDate();
-  m_endDates[last12Months] = QDate::currentDate();
-  m_endDates[next30Days] = QDate::currentDate().addDays(30);
-  m_endDates[next3Months] = QDate::currentDate().addMonths(3);
-  m_endDates[next6Months] = QDate::currentDate().addMonths(6);
-  m_endDates[next12Months] = QDate::currentDate().addMonths(12);
-  m_endDates[userDefined] = QDate();
+  MyMoneyTransactionFilter::translateDateRange(allDates,m_startDates[allDates],m_endDates[allDates]);
+  MyMoneyTransactionFilter::translateDateRange(untilToday,m_startDates[untilToday],m_endDates[untilToday]);
+  MyMoneyTransactionFilter::translateDateRange(currentMonth,m_startDates[currentMonth],m_endDates[currentMonth]);
+  MyMoneyTransactionFilter::translateDateRange(currentYear,m_startDates[currentYear],m_endDates[currentYear]);
+  MyMoneyTransactionFilter::translateDateRange(monthToDate,m_startDates[monthToDate],m_endDates[monthToDate]);
+  MyMoneyTransactionFilter::translateDateRange(yearToDate,m_startDates[yearToDate],m_endDates[yearToDate]);
+  MyMoneyTransactionFilter::translateDateRange(lastMonth,m_startDates[lastMonth],m_endDates[lastMonth]);
+  MyMoneyTransactionFilter::translateDateRange(lastYear,m_startDates[lastYear],m_endDates[lastYear]);
+  MyMoneyTransactionFilter::translateDateRange(last30Days,m_startDates[last30Days],m_endDates[last30Days]);
+  MyMoneyTransactionFilter::translateDateRange(last3Months,m_startDates[last3Months],m_endDates[last3Months]);
+  MyMoneyTransactionFilter::translateDateRange(last6Months,m_startDates[last6Months],m_endDates[last6Months]);
+  MyMoneyTransactionFilter::translateDateRange(last12Months,m_startDates[last12Months],m_endDates[last12Months]);
+  MyMoneyTransactionFilter::translateDateRange(next30Days,m_startDates[next30Days],m_endDates[next30Days]);
+  MyMoneyTransactionFilter::translateDateRange(next3Months,m_startDates[next3Months],m_endDates[next3Months]);
+  MyMoneyTransactionFilter::translateDateRange(next6Months,m_startDates[next6Months],m_endDates[next6Months]);
+  MyMoneyTransactionFilter::translateDateRange(next12Months,m_startDates[next12Months],m_endDates[next12Months]);
+  MyMoneyTransactionFilter::translateDateRange(userDefined,m_startDates[userDefined],m_endDates[userDefined]);
 
   connect(m_dateRange, SIGNAL(activated(int)), this, SLOT(slotDateRangeChanged(int)));
   connect(m_fromDate, SIGNAL(dateChanged(const QDate&)), this, SLOT(slotDateChanged()));
@@ -470,6 +488,7 @@ void KFindTransactionDlg::setupDetailsPage(void)
 {
   connect(m_typeBox, SIGNAL(activated(int)), this, SLOT(slotUpdateSelections()));
   connect(m_stateBox, SIGNAL(activated(int)), this, SLOT(slotUpdateSelections()));
+  connect(m_validityBox, SIGNAL(activated(int)), this, SLOT(slotUpdateSelections()));
 
   connect(m_nrButton, SIGNAL(clicked()), this, SLOT(slotNrSelected()));
   connect(m_nrRangeButton, SIGNAL(clicked()), this, SLOT(slotNrRangeSelected()));
@@ -512,7 +531,7 @@ void KFindTransactionDlg::addItemToFilter(const opTypeE op, const QCString& id)
   }
 }
 
-void KFindTransactionDlg::scanCheckListItems(QListViewItem* item, const opTypeE op)
+void KFindTransactionDlg::scanCheckListItems(const QListViewItem* item, const opTypeE op)
 {
   QListViewItem* it_v;
 
@@ -521,14 +540,14 @@ void KFindTransactionDlg::scanCheckListItems(QListViewItem* item, const opTypeE
       kMyMoneyCheckListItem* it_c = static_cast<kMyMoneyCheckListItem*>(it_v);
       if(it_c->type() == QCheckListItem::CheckBox) {
         if(it_c->isOn())
-          addItemToFilter(op, (*it_c).accountId());
+          addItemToFilter(op, (*it_c).id());
       }
       scanCheckListItems(it_v, op);
     }
   }
 }
 
-void KFindTransactionDlg::scanCheckListItems(QListView* view, const opTypeE op)
+void KFindTransactionDlg::scanCheckListItems(const QListView* view, const opTypeE op)
 {
   QListViewItem* it_v;
 
@@ -537,16 +556,15 @@ void KFindTransactionDlg::scanCheckListItems(QListView* view, const opTypeE op)
       kMyMoneyCheckListItem* it_c = static_cast<kMyMoneyCheckListItem*>(it_v);
       if(it_c->type() == QCheckListItem::CheckBox) {
         if(it_c->isOn())
-          addItemToFilter(op, (*it_c).accountId());
+          addItemToFilter(op, (*it_c).id());
       }
       scanCheckListItems(it_v, op);
     }
   }
 }
 
-void KFindTransactionDlg::slotSearch(void)
+void KFindTransactionDlg::setupFilter(void)
 {
-  // setup the filter from the dialog widgets
   m_filter.clear();
 
   // Text tab
@@ -556,9 +574,10 @@ void KFindTransactionDlg::slotSearch(void)
   }
 
   // Account tab
-  // if(!m_accountsView->allAccountsSelected()) {
+  // TOM: Why was this commented out? (Ace)
+  if(!m_accountsView->allAccountsSelected()) {
     m_filter.addAccount(m_accountsView->selectedAccounts());
-  //}
+  }
 
   // Date tab
   if(m_dateRange->currentItem() != 0) {
@@ -567,21 +586,22 @@ void KFindTransactionDlg::slotSearch(void)
 
   // Amount tab
   if((m_amountButton->isChecked() && m_amountEdit->isValid())) {
-    m_filter.setAmountFilter(m_amountEdit->getMoneyValue(), m_amountEdit->getMoneyValue());
+    m_filter.setAmountFilter(m_amountEdit->value(), m_amountEdit->value());
 
   } else if((m_amountRangeButton->isChecked()
       && (m_amountFromEdit->isValid() || m_amountToEdit->isValid()))) {
 
     MyMoneyMoney from(MyMoneyMoney::minValue), to(MyMoneyMoney::maxValue);
     if(m_amountFromEdit->isValid())
-      from = m_amountFromEdit->getMoneyValue();
+      from = m_amountFromEdit->value();
     if(m_amountToEdit->isValid())
-      to = m_amountToEdit->getMoneyValue();
+      to = m_amountToEdit->value();
 
     m_filter.setAmountFilter(from, to);
   }
 
   // Categories tab
+
   if(!m_categoriesView->allAccountsSelected()) {
     m_filter.addCategory(m_categoriesView->selectedAccounts());
   }
@@ -601,6 +621,9 @@ void KFindTransactionDlg::slotSearch(void)
   if(m_stateBox->currentItem() != 0)
     m_filter.addState(m_stateBox->currentItem());
 
+  if(m_validityBox->currentItem() != 0)
+    m_filter.addValidity(m_validityBox->currentItem());
+
   if(m_nrButton->isChecked() && !m_nrEdit->text().isEmpty())
     m_filter.setNumberFilter(m_nrEdit->text(), m_nrEdit->text());
 
@@ -608,6 +631,12 @@ void KFindTransactionDlg::slotSearch(void)
      && (!m_nrFromEdit->text().isEmpty() || !m_nrToEdit->text().isEmpty())) {
     m_filter.setNumberFilter(m_nrFromEdit->text(), m_nrToEdit->text());
   }
+}
+
+void KFindTransactionDlg::slotSearch(void)
+{
+  // setup the filter from the dialog widgets
+  setupFilter();
 
   // filter is setup, now fill the register
   slotRefreshView();
@@ -721,6 +750,11 @@ const QCString KFindTransactionDlg::accountId(const MyMoneyTransaction * const t
   return QCString();
 }
 
+bool KFindTransactionDlg::focusNextPrevChild(bool next)
+{
+  return KFindTransactionDlgDecl::focusNextPrevChild(next);
+}
+
 void KFindTransactionDlg::resizeEvent(QResizeEvent* ev)
 {
   // don't forget the resizer
@@ -840,3 +874,47 @@ void KFindTransactionDlg::update(const QCString& /* id */)
     slotSelectTransaction(id);
   }
 }
+
+bool KFindTransactionDlg::eventFilter(QObject* o, QEvent* e)
+{
+  bool rc = false;
+
+  if(o->isWidgetType()) {
+    if(e->type() == QEvent::KeyPress) {
+      const QWidget* w = dynamic_cast<const QWidget*>(o);
+      QKeyEvent *k = static_cast<QKeyEvent *> (e);
+      if(w == m_register) {
+        switch(k->key()) {
+          default:
+            break;
+
+          case Qt::Key_Return:
+          case Qt::Key_Enter:
+            rc = true;
+            slotSelectTransaction();
+            break;
+        }
+      }
+    }
+  }
+  return rc;
+}
+
+const MyMoneyMoney KFindTransactionDlg::balance(const int /* idx */) const
+{
+  return 0;
+}
+
+void KFindTransactionDlg::slotShowHelp(void)
+{
+  QString anchor = m_helpAnchor[m_criteriaTab->currentPage()];
+  if(anchor.isEmpty())
+    anchor = QString("details.search");
+
+  kapp->invokeHelp(anchor);
+}
+
+// vim:cin:si:ai:et:ts=2:sw=2:
+
+
+#include "kfindtransactiondlg.moc"
