@@ -404,6 +404,10 @@ void KNewAccountDlg::okClicked()
         delete e;
       }
     }
+    else
+    {
+      m_account.setInstitutionId(QCString());
+    }
   }
 
   m_account.setName(accountNameText);
@@ -460,7 +464,7 @@ void KNewAccountDlg::okClicked()
   {
     KConfig *kconfig = KGlobal::config();
     kconfig->setGroup("List Options");
-    if(kconfig->readBoolEntry("HideUnusedCategory", false) == true) {
+    if(kconfig->readBoolEntry("HideUnusedCategory", false) == true && !m_isEditing) {
       KMessageBox::information(this, i18n("You have selected to suppress the display of unused categories in the KMyMoney configuration dialog. The category you just created will therefore only be shown if it is used. Otherwise, it will be hidden in the accounts/categories view."), i18n("Hidden categories"), "NewHiddenCategory");
     }
   }
