@@ -32,7 +32,7 @@
 // ----------------------------------------------------------------------------
 // Project Includes
 
-#include "knewaccountwizarddecl.h"
+#include "../dialogs/knewaccountwizarddecl.h"
 #include "../mymoney/mymoneyaccount.h"
 #include "../mymoney/mymoneyscheduled.h"
 #include "../mymoney/mymoneyinstitution.h"
@@ -44,7 +44,7 @@
 
 class KNewAccountWizard : public KNewAccountWizardDecl  {
    Q_OBJECT
-public: 
+public:
   KNewAccountWizard(QWidget *parent=0, const char *name=0);
   ~KNewAccountWizard();
 
@@ -55,6 +55,17 @@ public:
     */
   const MyMoneyAccount account(void) const { return m_account; };
 
+  /**
+    * This method returns the account information about a brokerage
+    * account entered by the user. The value returned only makes sense,
+    * if account() returned an account of type investment. If the returned
+    * value does not contain a name then the user selected not to create
+    * a corresponding brokerage account to the investment account.
+    *
+    * @return MyMoneyAccount filled with information by the user
+    */
+  const MyMoneyAccount brokerageAccount(void) const { return m_brokerage; };
+
   /**
     * This method returns the parent account selected that is appropriate
     * to the account type selected by the user
@@ -66,7 +77,7 @@ public:
   /**
     * This method is used to preset the name of the account in the wizard
     *
-    * @param name name of the account
+    * @param accountName name of the account
     */
   void setAccountName(const QString& accountName);
 
@@ -104,7 +115,7 @@ public:
     * @param institution The institution
   **/
   void setInstitution(const MyMoneyInstitution& institution) { m_institution = institution; }
-    
+
 protected:
   /**
     * This method is used to reload the institution combo box
@@ -120,7 +131,7 @@ protected:
 
   /**
     * Pre-filter showPage so we can select the account type
-  **/
+    */
   void showPage(QWidget* page);
 
 public slots:
@@ -133,6 +144,10 @@ protected slots:
   void slotAccountType(const QString& sel);
   void slotCheckPageFinished(void);
   void slotNewPayee(const QString&);
+  void slotCurrencyChanged(int);
+  void slotPriceUpdate(void);
+
+  void help(void);
 
 signals:
   void newInstitutionClicked();
@@ -150,8 +165,10 @@ private:
   QString m_accountPaymentPageTitle;
   MyMoneyAccount m_account;
   MyMoneyAccount m_parent;
+  MyMoneyAccount m_brokerage;
   MyMoneySchedule m_schedule;
   MyMoneyInstitution m_institution;
+  QMap<QWidget*, QString>         m_helpAnchor;
 };
 
 #endif
