@@ -17,16 +17,23 @@
 #ifndef KNEWFILEDLG_H
 #define KNEWFILEDLG_H
 
+// ----------------------------------------------------------------------------
+// QT Includes
 #include <qdialog.h>
+
+// ----------------------------------------------------------------------------
+// KDE Includes
 #include <klocale.h>
 
-#include "knewfiledlgdecl.h"
+// ----------------------------------------------------------------------------
+// Project Includes
+#include "../dialogs/knewfiledlgdecl.h"
 
 // This dialog lets the user create/edit a file.
 // Use the second constructor to edit a file.
 class KNewFileDlg : public KNewFileDlgDecl  {
    Q_OBJECT
-public: 
+public:
   KNewFileDlg(QWidget *parent=0, const char *name=0, const char *title=0);
   KNewFileDlg(QString userName, QString userStreet,
     QString userTown, QString userCounty, QString userPostcode, QString userTelephone,
@@ -44,9 +51,13 @@ public:
   QString userTelephoneText;
   QString userEmailText;
 
+protected:
+  /// helper method for constructors
+  void init(const char* title);
+
 protected slots:
   void okClicked();
-
+  void loadFromKABC(void);
 };
 
 #endif
