@@ -31,6 +31,7 @@
 #include <kiconloader.h>
 #include <kmessagebox.h>
 #include <kconfig.h>
+#include <kstandarddirs.h>
 
 // ----------------------------------------------------------------------------
 // Project Includes
@@ -45,6 +46,8 @@ QColor KMyMoneyUtils::_gridColour;
 QFont  KMyMoneyUtils::_cellFont;
 QFont  KMyMoneyUtils::_headerFont;
 
+bool   KMyMoneyUtils::_expertMode;
+
 KMyMoneyUtils::KMyMoneyUtils()
 {
 }
@@ -60,7 +63,7 @@ const QString KMyMoneyUtils::accountTypeToString(const MyMoneyAccount::accountTy
   switch (accountType)
   {
     case MyMoneyAccount::Checkings:
-      returnString = i18n("Checkings");
+      returnString = i18n("Checking");
       break;
     case MyMoneyAccount::Savings:
       returnString = i18n("Savings");
@@ -101,6 +104,12 @@ const QString KMyMoneyUtils::accountTypeToString(const MyMoneyAccount::accountTy
     case MyMoneyAccount::AssetLoan:
       returnString = i18n("Investment Loan");
       break;
+    case MyMoneyAccount::Stock:
+      returnString = i18n("Stock");
+      break;
+    case MyMoneyAccount::Equity:
+      returnString = i18n("Equity");
+      break;
     default:
       returnString = i18n("Unknown");
   }
@@ -112,8 +121,8 @@ const MyMoneyAccount::accountTypeE KMyMoneyUtils::stringToAccountType(const QStr
 {
   MyMoneyAccount::accountTypeE rc = MyMoneyAccount::UnknownAccountType;
   QString tmp = type.lower();
-  
-  if(tmp == i18n("Checkings").lower())
+
+  if(tmp == i18n("Checking").lower())
     rc = MyMoneyAccount::Checkings;
   else if(tmp == i18n("Savings").lower())
     rc = MyMoneyAccount::Savings;
@@ -141,10 +150,59 @@ const MyMoneyAccount::accountTypeE KMyMoneyUtils::stringToAccountType(const QStr
     rc = MyMoneyAccount::Expense;
   else if(tmp == i18n("Investment Loan").lower())
     rc = MyMoneyAccount::AssetLoan;
+  else if(tmp == i18n("Stock").lower())
+    rc = MyMoneyAccount::Stock;
+  else if(tmp == i18n("Equity").lower())
+    rc = MyMoneyAccount::Equity;
 
   return rc;
 }
 
+const MyMoneySecurity::eSECURITYTYPE KMyMoneyUtils::stringToSecurity(const QString& txt)
+{
+  MyMoneySecurity::eSECURITYTYPE rc = MyMoneySecurity::SECURITY_NONE;
+  QString tmp = txt.lower();
+
+  if(tmp == i18n("Stock").lower())
+    rc = MyMoneySecurity::SECURITY_STOCK;
+  else if(tmp == i18n("Mutual Fund").lower())
+    rc = MyMoneySecurity::SECURITY_MUTUALFUND;
+  else if(tmp == i18n("Bond").lower())
+    rc = MyMoneySecurity::SECURITY_BOND;
+  else if(tmp == i18n("Currency").lower())
+    rc = MyMoneySecurity::SECURITY_CURRENCY;
+
+  return rc;
+}
+
+const QString KMyMoneyUtils::securityTypeToString(const MyMoneySecurity::eSECURITYTYPE securityType)
+{
+  QString returnString;
+
+  switch (securityType)
+  {
+  case MyMoneySecurity::SECURITY_STOCK:
+    returnString = i18n("Stock");
+    break;
+  case MyMoneySecurity::SECURITY_MUTUALFUND:
+    returnString = i18n("Mutual Fund");
+    break;
+  case MyMoneySecurity::SECURITY_BOND:
+    returnString = i18n("Bond");
+    break;
+  case MyMoneySecurity::SECURITY_CURRENCY:
+    returnString = i18n("Currency");
+    break;
+  case MyMoneySecurity::SECURITY_NONE:
+    returnString = i18n("None");
+    break;
+  default:
+    returnString = i18n("Unknown");
+  }
+
+  return returnString;
+}
+
 const MyMoneySchedule::occurenceE KMyMoneyUtils::stringToOccurence(const QString& text)
 {
   MyMoneySchedule::occurenceE occurence = MyMoneySchedule::OCCUR_ANY;
@@ -179,7 +237,7 @@ const MyMoneySchedule::occurenceE KMyMoneyUtils::stringToOccurence(const QString
   else if(tmp == i18n("Every other year").lower())
     occurence = MyMoneySchedule::OCCUR_EVERYOTHERYEAR;
 
-  return occurence;  
+  return occurence;
 }
 
 const QString KMyMoneyUtils::occurenceToString(const MyMoneySchedule::occurenceE occurence)
@@ -256,7 +314,7 @@ const QString KMyMoneyUtils::paymentMethodToString(MyMoneySchedule::paymentTypeE
       text = i18n("Other");
       break;
     case MyMoneySchedule::STYPE_WRITECHEQUE:
-      text = i18n("Write cheque");
+      text = i18n("Write check");
       break;
     case MyMoneySchedule::STYPE_ANY:
       text = i18n("Any (Error)");
@@ -268,7 +326,7 @@ const QString KMyMoneyUtils::paymentMethodToString(MyMoneySchedule::paymentTypeE
 const QString KMyMoneyUtils::scheduleTypeToString(MyMoneySchedule::typeE type)
 {
   QString text;
-  
+
   switch (type)
   {
     case MyMoneySchedule::TYPE_BILL:
@@ -293,7 +351,7 @@ const QString KMyMoneyUtils::scheduleTypeToString(MyMoneySchedule::typeE type)
 KGuiItem KMyMoneyUtils::splitGuiItem(void)
 {
   KIconLoader *ic = KGlobal::iconLoader();
-  
+
   KGuiItem splitGuiItem(  i18n("&Split"),
                           QIconSet(ic->loadIcon("split", KIcon::User, KIcon::SizeSmall)),
                           i18n("Split the amount into different categories."),
@@ -325,7 +383,7 @@ KGuiItem KMyMoneyUtils::accountsFilterGuiItem(void)
 
   return splitGuiItem;
 }
-  
+
 QPixmap KMyMoneyUtils::billScheduleIcon(int size)
 {
   KIconLoader *ic = KGlobal::iconLoader();
@@ -353,7 +411,7 @@ QPixmap KMyMoneyUtils::scheduleIcon(int size)
 const QString KMyMoneyUtils::homePageItemToString(const int idx)
 {
   QString rc;
-  
+
   switch(abs(idx)) {
     case 1:
       rc = i18n("Payments");
@@ -364,6 +422,9 @@ const QString KMyMoneyUtils::homePageItemToString(const int idx)
     case 3:
       rc = i18n("Payment accounts");
       break;
+    case 4:
+      rc = i18n("Favorite reports");
+      break;
     default:
       rc = "";
       break;
@@ -380,6 +441,8 @@ const int KMyMoneyUtils::stringToHomePageItem(const QString& txt)
     idx = 2;
   else if(txt == i18n("Payment accounts"))
     idx = 3;
+  else if(txt == i18n("Favorite reports"))
+    idx = 4;
   return idx;
 }
 
@@ -396,7 +459,7 @@ void KMyMoneyUtils::addDefaultHomePageItems(QStringList& list)
 bool KMyMoneyUtils::appendCorrectFileExt(QString& str, const QString& strExtToUse)
 {
   bool rc = false;
-  
+
   if(!str.isEmpty()) {
     //find last . delminator
     int nLoc = str.findRev('.');
@@ -478,7 +541,7 @@ void KMyMoneyUtils::newPayee(QWidget* parent, kMyMoneyPayee* payeeEdit, const QS
   // Ask the user if that is what he intended to do?
   QString msg = i18n("Do you want to add '%1' as payee/receiver ?").arg(payeeName);
 
-  if(KMessageBox::questionYesNo(parent, msg, i18n("New payee/receiver")) == KMessageBox::Yes) {
+  if(KMessageBox::questionYesNo(parent, msg, i18n("New payee/receiver"),KStdGuiItem::yes(),KStdGuiItem::no(),"NewPayee") == KMessageBox::Yes) {
     // for now, we just add the payee to the pool. In the future,
     // we could open a dialog and ask for all the other attributes
     // of the payee.
@@ -501,12 +564,17 @@ void KMyMoneyUtils::newPayee(QWidget* parent, kMyMoneyPayee* payeeEdit, const QS
 
 const QColor KMyMoneyUtils::defaultBackgroundColour(void)
 {
-  return QColor(255,255,204);
+  return KGlobalSettings::baseColor();
+  // return QColor(255,255,204);
 }
 
 const QColor KMyMoneyUtils::defaultListColour(void)
 {
-  return QColor(255,255,238);
+  QColor color = KGlobalSettings::alternateBackgroundColor();
+  if(!color.isValid())
+    color = defaultBackgroundColour();
+  return color;
+  // return QColor(255,255,238);
 }
 
 const QColor KMyMoneyUtils::defaultGridColour(void)
@@ -523,7 +591,7 @@ void KMyMoneyUtils::updateSettings(void)
 
   c = defaultBackgroundColour();
   _backgroundColour = config->readColorEntry("listBGColor", &c);
-  
+
   c = defaultListColour();
   _listColour = config->readColorEntry("listColor", &c);
 
@@ -542,5 +610,106 @@ void KMyMoneyUtils::updateSettings(void)
     _headerFont = config->readFontEntry("listHeaderFont", &f);
   else
     _headerFont = f;
+
+  config->setGroup("General Options");
+  _expertMode = config->readBoolEntry("ExpertMode", false);
+}
+
+void KMyMoneyUtils::checkConstants(void)
+{
+  Q_ASSERT(static_cast<int>(KLocale::ParensAround) == static_cast<int>(MyMoneyMoney::ParensAround));
+  Q_ASSERT(static_cast<int>(KLocale::BeforeQuantityMoney) == static_cast<int>(MyMoneyMoney::BeforeQuantityMoney));
+  Q_ASSERT(static_cast<int>(KLocale::AfterQuantityMoney) == static_cast<int>(MyMoneyMoney::AfterQuantityMoney));
+  Q_ASSERT(static_cast<int>(KLocale::BeforeMoney) == static_cast<int>(MyMoneyMoney::BeforeMoney));
+  Q_ASSERT(static_cast<int>(KLocale::AfterMoney) == static_cast<int>(MyMoneyMoney::AfterMoney));
+}
+
+QString KMyMoneyUtils::variableCSS(void)
+{
+  QColor tcolor = KGlobalSettings::textColor();
+
+  QString css;
+  css += "<style type=\"text/css\">\n<!--\n";
+
+  css += QString(".row-even { font-family: verdana, arial, helvetica; background-color: %1; color: %2; padding-top: 2px; padding-left: 20px; }\n").arg(backgroundColour().name()).arg(tcolor.name());
+  css += QString(".row-odd { font-family: verdana, arial, helvetica; background-color: %1; color: %2; padding-top: 2px; padding-left: 20px; }\n").arg(listColour().name()).arg(tcolor.name());
+
+  css += "-->\n</style>\n";
+  return css;
+}
+
+QString KMyMoneyUtils::findResource(const char* type, const QString& filename)
+{
+  QString language = KGlobal::locale()->language();
+  QString country = KGlobal::locale()->country();
+  QString rc, mask;
+
+  // check that the placeholder is present
+  if(!filename.find("%1")) {
+    qWarning("%%1 not found in '%s'", filename.latin1());
+    return filename;
+  }
+
+  // search the given resource
+  mask = filename.arg("_%1.%2");
+  rc = KGlobal::dirs()->findResource(type, mask.arg(country).arg(language));
+  if(rc.isEmpty()) {
+    mask = filename.arg("_%1");
+    rc = KGlobal::dirs()->findResource(type, mask.arg(language));
+  }
+  if(rc.isEmpty()) {
+    // qDebug(QString("html/home_%1.html not found").arg(country).latin1());
+    rc = KGlobal::dirs()->findResource(type, mask.arg(country));
+  }
+  if(rc.isEmpty()) {
+    rc = KGlobal::dirs()->findResource(type, filename.arg(""));
+  }
+
+  if(rc.isEmpty()) {
+    qWarning("No resource found for (%s,%s)", type, filename.latin1());
+  }
+  return rc;
+}
+
+const MyMoneySplit KMyMoneyUtils::stockSplit(const MyMoneyTransaction& t)
+{
+  QValueList<MyMoneySplit>::ConstIterator it_s;
+  for(it_s = t.splits().begin(); it_s != t.splits().end(); ++it_s) {
+    if(!(*it_s).accountId().isEmpty()) {
+      MyMoneyAccount acc = MyMoneyFile::instance()->account((*it_s).accountId());
+      if(acc.accountType() == MyMoneyAccount::Stock) {
+        return *it_s;
+      }
+    }
+  }
+  return MyMoneySplit();
+}
+
+const KMyMoneyUtils::transactionTypeE KMyMoneyUtils::transactionType(const MyMoneyTransaction& t)
+{
+  if(!stockSplit(t).id().isEmpty())
+    return InvestmentTransaction;
+
+  if(t.splitCount() < 2) {
+    return Unknown;
+  } else if(t.splitCount() > 2) {
+    // FIXME check for loan transaction here
+    return SplitTransaction;
+  }
+  QCString ida, idb;
+  ida = t.splits()[0].accountId();
+  idb = t.splits()[1].accountId();
+  if(ida.isEmpty() || idb.isEmpty())
+    return Unknown;
+
+  MyMoneyAccount a, b;
+  a = MyMoneyFile::instance()->account(ida);
+  b = MyMoneyFile::instance()->account(idb);
+  if((a.accountGroup() == MyMoneyAccount::Asset
+   || a.accountGroup() == MyMoneyAccount::Liability)
+  && (b.accountGroup() == MyMoneyAccount::Asset
+   || b.accountGroup() == MyMoneyAccount::Liability))
+    return Transfer;
+  return Normal;
 }
 
