@@ -32,8 +32,7 @@
 
 MyMoneyAccount::MyMoneyAccount()
 {
-  m_file = 0;
-  m_openingBalance = 0;
+  m_openingBalance = MyMoneyMoney(0);
   m_accountType = UnknownAccountType;
 }
 
@@ -208,6 +207,7 @@ const MyMoneyAccount::accountTypeE MyMoneyAccount::accountGroup(MyMoneyAccount::
     case MyMoneyAccount::MoneyMarket:
     case MyMoneyAccount::CertificateDep:
     case MyMoneyAccount::AssetLoan:
+    case MyMoneyAccount::Stock:
       return MyMoneyAccount::Asset;
 
     case MyMoneyAccount::CreditCard:
@@ -221,25 +221,31 @@ const MyMoneyAccount::accountTypeE MyMoneyAccount::accountGroup(MyMoneyAccount::
 
 const bool MyMoneyAccount::operator == (const MyMoneyAccount& right) const
 {
-  return ((m_id == right.m_id) &&
+  return (static_cast<const MyMoneyKeyValueContainer>(*this) == static_cast<const MyMoneyKeyValueContainer>(right) &&
+      (m_id == right.m_id) &&
       (m_accountList == right.m_accountList) &&
       (m_accountType == right.m_accountType) &&
-      (m_description == right.m_description) &&
       (m_lastModified == right.m_lastModified) &&
       (m_lastReconciliationDate == right.m_lastReconciliationDate) &&
-      (m_name == right.m_name) &&
-      (m_number == right.m_number) &&
+      ((m_name.length() == 0 && right.m_name.length() == 0) || (m_name == right.m_name)) &&
+      ((m_number.length() == 0 && right.m_number.length() == 0) || (m_number == right.m_number)) &&
+      ((m_description.length() == 0 && right.m_description.length() == 0) || (m_description == right.m_description)) &&
       (m_openingBalance == right.m_openingBalance) &&
       (m_openingDate == right.m_openingDate) &&
       (m_parentAccount == right.m_parentAccount) &&
+      (m_currencyId == right.m_currencyId) &&
       (m_institution == right.m_institution) );
 }
 
 const MyMoneyAccount::accountTypeE MyMoneyAccount::accountGroup(void) const
 {
-  return accountGroup(m_accountType);  
+  return accountGroup(m_accountType);
 }
 
+void MyMoneyAccount::setCurrencyId(const QCString& id)
+{
+  m_currencyId = id;
+}
 
 MyMoneyAccountLoan::MyMoneyAccountLoan(const MyMoneyAccount& acc)
  : MyMoneyAccount(acc)
@@ -264,11 +270,11 @@ const MyMoneyMoney MyMoneyAccountLoan::interestRate(const QDate& date) const
 
   if(!date.isValid())
     return rate;
-      
+
   key.sprintf("ir-%04d-%02d-%02d", date.year(), date.month(), date.day());
-  
+
   QRegExp regExp("ir-(\\d{4})-(\\d{2})-(\\d{2})");
-  
+
   QMap<QCString, QString>::ConstIterator it;
 
   for(it = pairs().begin(); it != pairs().end(); ++it) {
@@ -277,7 +283,7 @@ const MyMoneyMoney MyMoneyAccountLoan::interestRate(const QDate& date) const
         val = *it;
       else
         break;
-        
+
     } else if(!val.isEmpty())
       break;
   }
@@ -285,7 +291,7 @@ const MyMoneyMoney MyMoneyAccountLoan::interestRate(const QDate& date) const
   if(!val.isEmpty()) {
     rate = MyMoneyMoney(val);
   }
-    
+
   return rate;
 }
 
@@ -293,7 +299,7 @@ void MyMoneyAccountLoan::setInterestRate(const QDate& date, const MyMoneyMoney&
 {
   if(!date.isValid())
     return;
-    
+
   QCString key;
   key.sprintf("ir-%04d-%02d-%02d", date.year(), date.month(), date.day());
   setValue(key, value.toString());
@@ -318,7 +324,7 @@ void MyMoneyAccountLoan::setInterestCalculation(const MyMoneyAccountLoan::intere
 const QDate MyMoneyAccountLoan::nextInterestChange(void) const
 {
   QDate rc;
-  
+
   QRegExp regExp("(\\d{4})-(\\d{2})-(\\d{2})");
   if(regExp.search(value("interest-nextchange")) != -1) {
     rc.setYMD(regExp.cap(1).toInt(), regExp.cap(2).toInt(), regExp.cap(3).toInt());
@@ -334,10 +340,10 @@ void MyMoneyAccountLoan::setNextInterestChange(const QDate& date)
 const int MyMoneyAccountLoan::interestChangeFrequency(int* unit) const
 {
   int rc = -1;
-  
+
   if(unit)
     *unit = 1;
-  
+
   QRegExp regExp("(\\d+)/(\\d{1})");
   if(regExp.search(value("interest-changefrequency")) != -1) {
     rc = regExp.cap(1).toInt();
@@ -392,7 +398,7 @@ void MyMoneyAccountLoan::setFinalPayment(const MyMoneyMoney& finalPayment)
 
 const unsigned int MyMoneyAccountLoan::term(void) const
 {
-  return value("term").toUInt();  
+  return value("term").toUInt();
 }
 
 void MyMoneyAccountLoan::setTerm(const unsigned int payments)
@@ -420,3 +426,12 @@ void MyMoneyAccountLoan::setPayee(const QCString& payee)
   setValue("payee", payee);
 }
 
+const QCString MyMoneyAccountLoan::interestAccountId(void) const
+{
+  return QCString();
+}
+
+void MyMoneyAccountLoan::setInterestAccountId(const QCString& /* id */)
+{
+
+}
