@@ -17,6 +17,10 @@
 #ifndef MYMONEYACCOUNT_H
 #define MYMONEYACCOUNT_H
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 // ----------------------------------------------------------------------------
 // QT Includes
 
@@ -32,7 +36,7 @@
 #include "mymoneymoney.h"
 #include "mymoneyutils.h"
 #include "mymoneykeyvaluecontainer.h"
-
+#include <kmymoney/export.h>
 class MyMoneyTransaction;
 class MyMoneyInstitution;
 class MyMoneyFile;
@@ -61,6 +65,7 @@ class MyMoneyFile;
   * @li  Income
   * @li  Expense
   * @li  Loan (given)
+  * @li  Equity
   *
   * @see MyMoneyInstitution
   * @see MyMoneyFile
@@ -69,7 +74,7 @@ class MyMoneyFile;
   * @author Thomas Baumgart 2002
   *
 **/
-class MyMoneyAccount : public MyMoneyKeyValueContainer
+class KMYMONEY_EXPORT MyMoneyAccount : public MyMoneyKeyValueContainer
 {
 public:
 
@@ -111,7 +116,9 @@ public:
     Income,               /**< Denotes an income account */
     Expense,              /**< Denotes an expense account */
     AssetLoan,            /**< Denotes a loan (asset of the owner of this object) */
-    
+    Stock,                /**< Denotes an security account as sub-account for an investment */
+    Equity,               /**< Denotes an equity account e.g. opening/closeing balance */
+
     /* insert new account types above this line */
     MaxAccountTypes       /**< Denotes the number of different account types */
   }accountTypeE;
@@ -125,8 +132,8 @@ public:
     * This is the constructor for a new account known to the current file
     * This is the only constructor that will set the attribute m_openingDate
     * to a correct value.
-    * @param file pointer to current MyMoneyFile object
-    * @param ID id assigned to the account
+    *
+    * @param id id assigned to the account
     * @param right account definition
     */
   MyMoneyAccount(const QCString& id, const MyMoneyAccount& right);
@@ -174,7 +181,7 @@ public:
   static const MyMoneyAccount::accountTypeE accountGroup(MyMoneyAccount::accountTypeE type);
 
   const MyMoneyAccount::accountTypeE accountGroup(void) const;
-  
+
   /**
     * This method returns the ID of the account under which it is known
     * inside the MyMoneyFile.
@@ -184,14 +191,6 @@ public:
     */
   const QCString id(void) const { return m_id; }
 
-  /**
-    * This method returns the pointer to MyMoneyFile object this account
-    * belongs to.
-    * @return pointer to MyMoneyFile object
-    * @see m_file, setFile()
-    */
-  MyMoneyFile* file(void) const { return m_file; }
-
   /**
     * This method returns the id of the MyMoneyInstitution object this account
     * belongs to.
@@ -442,7 +441,20 @@ public:
     */
   const accountTypeE accountType(void) const {return m_accountType; };
 
-  // Statics
+  /**
+    * This method retrieves the id of the currency used with this account.
+    * If the return value is empty, the base currency should be used.
+    *
+    * @return id of currency
+    */
+  const QCString currencyId(void) const { return m_currencyId; };
+
+  /**
+    * This method sets the id of the currency used with this account.
+    *
+    * @param id ID of currency to be associated with this account.
+    */
+  void setCurrencyId(const QCString& id);
 
 private:
   /**
@@ -450,12 +462,6 @@ private:
     */
   accountTypeE m_accountType;
 
-  /**
-    * This member variable keeps a pointer to the MyMoneyFile object
-    * that this object belongs to.
-    */
-  MyMoneyFile* m_file;
-
   /**
     * This member variable keeps the ID of the MyMoneyInstitution object
     * that this object belongs to.
@@ -531,6 +537,11 @@ private:
     * This member contains the ID of the parent account
     */
   QCString m_parentAccount;
+
+  /**
+    * This member contains the ID of the currency associated with this account
+    */
+  QCString m_currencyId;
 };
 
 /**
@@ -540,14 +551,14 @@ private:
   * laon relevant data stored in the key value container of the MyMoneyAccount
   * object.
   */
-class MyMoneyAccountLoan : public MyMoneyAccount
+class KMYMONEY_EXPORT MyMoneyAccountLoan : public MyMoneyAccount
 {
 public:
   enum interestDueE {
     paymentDue = 0,
     paymentReceived
   };
-  
+
   MyMoneyAccountLoan() {};
   MyMoneyAccountLoan(const MyMoneyAccount&);
   ~MyMoneyAccountLoan() {};
@@ -574,7 +585,10 @@ public:
   void setPeriodicPayment(const MyMoneyMoney& payment);
   const QCString payee(void) const;
   void setPayee(const QCString& payee);
+  const QCString interestAccountId(void) const;
+  void setInterestAccountId(const QCString& id);
 };
 
 #endif
 
+
