@@ -17,15 +17,19 @@
 #ifndef MYMONEYPAYEE_H
 #define MYMONEYPAYEE_H
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <qstring.h>
 #include <qcstring.h>
-
+#include <kmymoney/export.h>
 /**
   * This class represents a payee or receiver within the MyMoney engine
   *
   * @author Thomas Baumgart
   */
-class MyMoneyPayee {
+class KMYMONEY_EXPORT MyMoneyPayee {
 private:
 	// Simple fields
 	QString m_name;
