@@ -22,6 +22,10 @@
 #ifndef MYMONEYSCHEDULED_H
 #define MYMONEYSCHEDULED_H
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 // ----------------------------------------------------------------------------
 // QT Includes
 
@@ -35,6 +39,7 @@
 
 #include "mymoneytransaction.h"
 #include "mymoneyaccount.h"
+#include <kmymoney/export.h>
 
 /**
   * @author Michael Edwardes
@@ -47,7 +52,7 @@
   * @short A class to represent a schedule.
   * @see MyMoneyScheduled
   */
-class MyMoneySchedule {
+class KMYMONEY_EXPORT MyMoneySchedule {
 public:
   /**
     * This enum is used to describe all the possible schedule frequencies.
