@@ -23,6 +23,10 @@
 #ifndef MYMONEYSPLIT_H
 #define MYMONEYSPLIT_H
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 // ----------------------------------------------------------------------------
 // QT Includes
 
@@ -35,6 +39,7 @@
 #include "mymoneyexception.h"
 #include "mymoneyutils.h"
 #include "mymoneymoney.h"
+#include <kmymoney/export.h>
 
 /**
   * @author Thomas Baumgart
@@ -43,7 +48,7 @@
 /**
   * This class represents a split of a transaction.
   */
-class MyMoneySplit {
+class KMYMONEY_EXPORT MyMoneySplit {
 public:
   /**
     * This enum defines the possible reconciliation states a split
@@ -74,6 +79,7 @@ public:
 
   const MyMoneyMoney shares(void) const { return m_shares; };
   const MyMoneyMoney value(void) const { return m_value; };
+  const MyMoneyMoney value(const QCString& transactionCurrencyId, const QCString& splitCurrencyId) const;
   const QCString accountId(void) const { return m_account; };
   const QString memo(void) const { return m_memo; };
   const reconcileFlagE reconcileFlag(void) const { return m_reconcileFlag; };
@@ -83,9 +89,25 @@ public:
   const QCString action(void) const { return m_action; };
   const QString number(void) const { return m_number; };
   const bool isAmortizationSplit(void) const { return m_action == ActionAmortization; };
-  
+
   void setShares(const MyMoneyMoney& shares);
   void setValue(const MyMoneyMoney& value);
+
+  /**
+    * This method is used to set either the shares or the value depending on
+    * the currencies assigned to the split/account and the transaction.
+    *
+    * If @p transactionCurrencyId equals @p splitCurrencyId this method
+    * calls setValue(MyMoneyMoney) otherwise setShares(MyMoneyMoney).
+    *
+    * @param value the value to be assiged
+    * @param transactionCurrencyId the id of the currency assigned to the transaction
+    * @param splitCurrencyId the id of the currency assigned to the split (i.e. the
+    *                        the id of the currency assigned to the account that is
+    *                        referenced by the split)
+    */
+  void setValue(const MyMoneyMoney& value, const QCString& transactionCurrencyId, const QCString& splitCurrencyId);
+
   void setAccountId(const QCString& account);
   void setMemo(const QString& memo);
   void setReconcileFlag(const reconcileFlagE flag);
@@ -100,9 +122,16 @@ public:
   static const char ActionTransfer[];
   static const char ActionWithdrawal[];
   static const char ActionATM[];
+
   static const char ActionAmortization[];
   static const char ActionInterest[];
-  
+
+  static const char ActionBuyShares[];  // negative amount is sellShares
+  static const char ActionDividend[];
+  static const char ActionReinvestDividend[];
+  static const char ActionYield[];
+  static const char ActionAddShares[];  // negative amount is removeShares
+
 private:
   /**
     * This member contains the ID of the transaction
