@@ -39,9 +39,11 @@ void MyMoneyTransactionTest::testEmptyConstructor() {
 void MyMoneyTransactionTest::testSetFunctions() {
 	m->setMemo("Memo");
 	m->setPostDate(QDate(1,2,3));
+	m->setBankID("BankID");
 
 	CPPUNIT_ASSERT(m->postDate() == QDate(1,2,3));
 	CPPUNIT_ASSERT(m->memo() == "Memo");
+	CPPUNIT_ASSERT(m->bankID() == "BankID");
 }
 
 void MyMoneyTransactionTest::testConstructor() {
@@ -52,6 +54,7 @@ void MyMoneyTransactionTest::testConstructor() {
 	CPPUNIT_ASSERT(a.entryDate() == QDate::currentDate());
 	CPPUNIT_ASSERT(a.memo() == "Memo");
 	CPPUNIT_ASSERT(a.postDate() == QDate(1,2,3));
+	CPPUNIT_ASSERT(a.bankID() == "BankID");
 }
 
 void MyMoneyTransactionTest::testCopyConstructor() {
@@ -64,6 +67,7 @@ void MyMoneyTransactionTest::testCopyConstructor() {
 	CPPUNIT_ASSERT(n.entryDate() == QDate::currentDate());
 	CPPUNIT_ASSERT(n.memo() == "Memo");
 	CPPUNIT_ASSERT(n.postDate() == QDate(1,2,3));
+	CPPUNIT_ASSERT(n.bankID() == "BankID");
 	
 }
 
@@ -79,6 +83,7 @@ void MyMoneyTransactionTest::testAssignmentConstructor() {
 	CPPUNIT_ASSERT(n.entryDate() == QDate::currentDate());
 	CPPUNIT_ASSERT(n.memo() == "Memo");
 	CPPUNIT_ASSERT(n.postDate() == QDate(1,2,3));
+	CPPUNIT_ASSERT(n.bankID() == "BankID");
 }
 
 void MyMoneyTransactionTest::testEquality() {
@@ -248,7 +253,7 @@ void MyMoneyTransactionTest::testExtractSplit() {
 }
 
 void MyMoneyTransactionTest::testSplitSum() {
-	CPPUNIT_ASSERT(m->splitSum() == 0);
+	CPPUNIT_ASSERT(m->splitSum().isZero());
 
 	testAddSplits();
 
@@ -261,19 +266,19 @@ void MyMoneyTransactionTest::testSplitSum() {
 
 	m->modifySplit(s1);
 	m->modifySplit(s2);
-	CPPUNIT_ASSERT(m->splitSum() == 0);
+	CPPUNIT_ASSERT(m->splitSum().isZero());
 
 	s1.setValue(1234);
 	m->modifySplit(s1);
-	CPPUNIT_ASSERT(m->splitSum() == 1234);
+	CPPUNIT_ASSERT(m->splitSum() == MyMoneyMoney(1234));
 
 	s2.setValue(-1234);
 	m->modifySplit(s2);
-	CPPUNIT_ASSERT(m->splitSum() == 0);
+	CPPUNIT_ASSERT(m->splitSum().isZero());
 
 	s1.setValue(5678);
 	m->modifySplit(s1);
-	CPPUNIT_ASSERT(m->splitSum() == 4444);
+	CPPUNIT_ASSERT(m->splitSum() == MyMoneyMoney(4444));
 }
 
 void MyMoneyTransactionTest::testIsLoanPayment() {
@@ -327,8 +332,8 @@ void MyMoneyTransactionTest::testAddDuplicateAccount() {
 		unexpectedException(e);
 	}
 
-	CPPUNIT_ASSERT(m->splits()[0].value() == 200);
-	CPPUNIT_ASSERT(m->splits()[1].value() == 400);
+	CPPUNIT_ASSERT(m->splits()[0].value() == MyMoneyMoney(200));
+	CPPUNIT_ASSERT(m->splits()[1].value() == MyMoneyMoney(400));
 }
 
 void MyMoneyTransactionTest::testModifyDuplicateAccount() {
@@ -341,7 +346,7 @@ void MyMoneyTransactionTest::testModifyDuplicateAccount() {
 		m->modifySplit(split);
 		CPPUNIT_ASSERT(m->splitCount() == 1);
 		CPPUNIT_ASSERT(m->accountReferenced("A000001") == true);
-		CPPUNIT_ASSERT(m->splits()[0].value() == 300);
+		CPPUNIT_ASSERT(m->splits()[0].value() == MyMoneyMoney(300));
 	
 	} catch(MyMoneyException *e) {
 		unexpectedException(e);
