@@ -203,6 +203,12 @@ void MyMoneyStorageANON::writeSplit(QDomElement& splitElement, const MyMoneySpli
   MyMoneyMoney hidevalue = split.value() * factor;
   MyMoneyMoney hideshares = split.shares() * factor;
 
+  // make sure, we don't screw up the autocalc stuff
+  if(split.value() == MyMoneyMoney::autoCalc)
+    hidevalue = MyMoneyMoney::autoCalc;
+  if(split.shares() == MyMoneyMoney::autoCalc)
+    hideshares = MyMoneyMoney::autoCalc;
+
   splitElement.setAttribute(QString("value"), hidevalue.toString());
   splitElement.setAttribute(QString("shares"), hideshares.toString());
   splitElement.setAttribute(QString("memo"), QString(transactionId) + "/" + QString(split.id()));
