@@ -227,7 +227,7 @@ void KAccountListItem::update(const QCString& accountId)
         m_valueValid = file->totalValueValid(accountId);
       } else {
         //value = file->accountValue(accountId, QDate::currentDate());
-	value = file->accountValue(accountId);
+  value = file->accountValue(accountId);
         m_valueValid = file->accountValueValid(accountId);
       }
 
@@ -392,6 +392,14 @@ void KAccountListItem::paintCell(QPainter *p, const QColorGroup & cg, int column
   }
 }
 
+bool KAccountListItem::isChildOf(const QListViewItem* const item) const
+{
+  QListViewItem *p = parent();
+  while(p && p != item) {
+    p = p->parent();
+  }
+  return (p != 0);
+}
 
 
 KAccountIconItem::KAccountIconItem(QIconView* parent, const MyMoneyAccount& account, const QPixmap& pixmap )
