@@ -450,6 +450,27 @@ void KAccountsView::refresh(const QCString& selectAccount)
   m_hideCategory = config->readBoolEntry("HideUnusedCategory", false);
   bool accountUsed;
 
+  QMap<QCString, bool> isOpen;
+  // remember the id of the current selected item
+  KAccountListItem* item = dynamic_cast<KAccountListItem*>(accountListView->selectedItem());
+  QCString selectedItemId = (item) ? item->accountID() : QCString();
+
+  // keep a map of all 'expanded' accounts
+  QListViewItemIterator it_lvi(accountListView);
+  while(it_lvi.current()) {
+    item = dynamic_cast<KAccountListItem*>(it_lvi.current());
+    if(item && item->isOpen()) {
+      isOpen[item->accountID()] = true;
+    }
+    ++it_lvi;
+  }
+
+  // remember the upper left corner of the viewport
+  QPoint startPoint = accountListView->viewportToContents(QPoint(0, 0));
+
+  // turn off updates to avoid flickering during reload
+  accountListView->setUpdatesEnabled(false);
+
   // Disable the note about hidden categories
   m_hiddenCategories->hide();
 
@@ -707,6 +728,27 @@ void KAccountsView::refresh(const QCString& selectAccount)
     }
   }
 
+  // scan through the list of accounts and re-expand those that were
+  // expanded and re-select the one that was probably selected before
+  it_lvi = QListViewItemIterator(accountListView);
+  while(it_lvi.current()) {
+    item = dynamic_cast<KAccountListItem*>(it_lvi.current());
+    if(item) {
+      if(item->accountID() == selectedItemId)
+        accountListView->setSelected(item, true);
+      if(isOpen.find(item->accountID()) != isOpen.end())
+        item->setOpen(true);
+    }
+    ++it_lvi;
+  }
+
+  // reposition viewport
+  accountListView->setContentsPos(startPoint.x(), startPoint.y());
+
+  // turn updates back on
+  accountListView->setUpdatesEnabled(true);
+  accountListView->repaintContents();
+
   m_accountMap.clear();
   m_transactionCountMap.clear();
 
