@@ -111,6 +111,27 @@ void KCategoriesView::slotRefreshView(void)
   categoryListView->header()->setFont(KMyMoneyUtils::headerFont());
   bool accountUsed;
 
+  QMap<QCString, bool> isOpen;
+  // remember the id of the current selected item
+  KCategoryListItem* item = dynamic_cast<KCategoryListItem*>(categoryListView->selectedItem());
+  QCString selectedItemId = (item) ? item->accountID() : QCString();
+
+  // keep a map of all 'expanded' accounts
+  QListViewItemIterator it_lvi(categoryListView);
+  while(it_lvi.current()) {
+    item = dynamic_cast<KCategoryListItem*>(it_lvi.current());
+    if(item && item->isOpen()) {
+      isOpen[item->accountID()] = true;
+    }
+    ++it_lvi;
+  }
+
+  // remember the upper left corner of the viewport
+  QPoint startPoint = categoryListView->viewportToContents(QPoint(0, 0));
+
+  // turn off updates to avoid flickering during reload
+  categoryListView->setUpdatesEnabled(false);
+
   // Disable the note about hidden categories
   m_hiddenCategories->hide();
 
@@ -196,6 +217,27 @@ void KCategoriesView::slotRefreshView(void)
     delete e;
   }
 
+  // scan through the list of accounts and re-expand those that were
+  // expanded and re-select the one that was probably selected before
+  it_lvi = QListViewItemIterator(categoryListView);
+  while(it_lvi.current()) {
+    item = dynamic_cast<KCategoryListItem*>(it_lvi.current());
+    if(item) {
+      if(item->accountID() == selectedItemId)
+        categoryListView->setSelected(item, true);
+      if(isOpen.find(item->accountID()) != isOpen.end())
+        item->setOpen(true);
+    }
+    ++it_lvi;
+  }
+
+  // reposition viewport
+  categoryListView->setContentsPos(startPoint.x(), startPoint.y());
+
+  // turn updates back on
+  categoryListView->setUpdatesEnabled(true);
+  categoryListView->repaintContents();
+
   refreshProfits();
 
   // free some memory (we don't need this map anymore)
