@@ -26,6 +26,7 @@
 // QT Includes
 #include <qwidget.h>
 class QVBoxLayout;
+class QFrame;
 
 // ----------------------------------------------------------------------------
 // KDE Includes
@@ -36,29 +37,35 @@ class QVBoxLayout;
 
 #include "../mymoney/mymoneyscheduled.h"
 #include "../mymoney/mymoneyaccount.h"
+#include "../views/kmymoneyview.h"
 
 /**
   * Displays a 'home page' for the user.  Similar to concepts used in
   * quicken and m$-money.
   *
   * @author Michael Edwardes
-  * $Id: khomeview.h,v 1.7 2003/09/01 17:50:34 mte Exp $
   *
   * @short A view containing the home page for kmymoney2.
 **/
-class KHomeView : public QWidget  {
-   Q_OBJECT
+class KHomeView : public KMyMoneyViewBase
+{
+  Q_OBJECT
 
 private:
   KHTMLPart *m_part;
   QVBoxLayout *m_qvboxlayoutPage;
   QString m_filename;
-  
+  bool    m_showAllSchedules;
+
 signals:
-  void signalViewActivated();
+  /**
+    * This signal is emitted whenever this view is activated.
+    */
+  void signalViewActivated(void);
+
   void ledgerSelected(const QCString& id, const QCString& transaction);
   void scheduleSelected(const QCString& id);
-
+  void reportSelected(const QCString& id);
 
 public:
   /**
@@ -97,14 +104,16 @@ protected:
     Preferred = 1,          ///< show preferred accounts
     Payment = 2             ///< show payment accounts
   };
-  
+
   void showPayments(void);
   void showPaymentEntry(const MyMoneySchedule&);
   void showAccounts(paymentTypeE type, const QString& hdr);
   void showAccountEntry(const MyMoneyAccount&);
+  void showFavoriteReports();
+
   const QString link(const QString& view, const QString& query) const;
   const QString linkend(void) const;
-  
+
 public slots:
   void slotOpenURL(const KURL &url, const KParts::URLArgs& args);
 
