@@ -215,12 +215,12 @@ void KInvestmentView::slotRemoveInvestment()
   }
 }
 
-void KInvestmentView::slotEditInvestment()
+void KInvestmentView::slotEditInvestment(void)
 {
   slotItemDoubleClicked(investmentTable->selectedItem(), QPoint(), 0);
 }
 
-void KInvestmentView::slotUpdatePrice()
+void KInvestmentView::slotUpdatePrice(void)
 {
   KInvestmentListItem *pItem = dynamic_cast<KInvestmentListItem*>(investmentTable->selectedItem());
   if(pItem)
@@ -230,7 +230,7 @@ void KInvestmentView::slotUpdatePrice()
   }
 }
 
-void KInvestmentView::slotAddPrice()
+void KInvestmentView::slotAddPrice(void)
 {
   KInvestmentListItem *pItem = dynamic_cast<KInvestmentListItem*>(investmentTable->selectedItem());
   if(pItem) {
@@ -238,7 +238,13 @@ void KInvestmentView::slotAddPrice()
     dlg.m_commodity->setSecurity(MyMoneyFile::instance()->security(pItem->securityId()));
     dlg.m_currency->setSecurity(pItem->tradingCurrency());
     if(dlg.exec()) {
-      KCurrencyCalculator calc(dlg.m_commodity->security(), dlg.m_currency->security(), MyMoneyMoney(1,1), MyMoneyMoney(1,1), dlg.date());
+      MyMoneyPrice oldPrice = MyMoneyFile::instance()->price(dlg.m_commodity->security().id(), dlg.m_currency->security().id());
+
+      KConfig* kconfig = KGlobal::config();
+      kconfig->setGroup("General Options");
+      signed64 fract = MyMoneyMoney::precToDenom(kconfig->readNumEntry("PricePrecision", 4));
+
+      KCurrencyCalculator calc(dlg.m_commodity->security(), dlg.m_currency->security(), MyMoneyMoney(1,1), oldPrice.rate(), dlg.date(), fract);
 
       calc.m_updateButton->setChecked(true);
       calc.m_updateButton->hide();
