@@ -44,7 +44,7 @@ class KPushButton;
 class kMyMoneyTransactionFormTable;
 
 /**
-  *@author Thomas Baumgart
+  * @author Thomas Baumgart
   */
 
 /**
@@ -54,46 +54,70 @@ class kMyMoneyTransactionFormTable;
   *
   * @code
   *
-  * +------------------------------------------------------------------------------+
-  * | formLayout                                                                   |
-  * |                                                                              |
-  * | +---------------------------------------------------+   +------------------+ |
-  * | | ledgerLayout                                      |   | buttonLayout     | |
-  * | |                                                   |   |                  | |
-  * | | +-----------------------------------------------+ |   | +--------------+ | |
-  * | | | kMyMoneyRegisterCheckings                     | |   | | KPushButton  | | |
-  * | | |                                               | |   | +--------------+ | |
-  * | | |                                               | |   |                  | |
-  * | | |                                               | |   | +--------------+ | |
-  * | | |                                               | |   | | KPushButton  | | |
-  * | | |                                               | |   | +--------------+ | |
-  * | | |                                               | |   |                  | |
-  * | | |                                               | |   |                  | |
-  * | | +-----------------------------------------------+ |   |       -----      | |
-  * | | +-----------------------------------------------+ |   |         |        | |
-  * | | | Summary Line                                  | |   |         |        | |
-  * | | +-----------------------------------------------+ |   |       -----      | |
-  * | | +-----------------------------------------------+ |   |   QSpacerItem    | |
-  * | | | kMyMoneyTransactionForm                       | |   |                  | |
-  * | | |                                               | |   |                  | |
-  * | | |                                               | |   |                  | |
-  * | | |                                               | |   |                  | |
-  * | | |                                               | |   |                  | |
-  * | | |                                               | |   |                  | |
-  * | | +-----------------------------------------------+ |   |                  | |
-  * | +---------------------------------------------------+   +------------------+ |
-  * +------------------------------------------------------------------------------+
+  * +---------------------------------------------------------+
+  * | formLayout                                              |
+  * |                                                         |
+  * | +---------------------------------------------------+   |
+  * | | ledgerLayout                                      |   |
+  * | |                                                   |   |
+  * | | +-----------------------------------------------+ |   |
+  * | | | kMyMoneyRegisterCheckings                     | |   |
+  * | | |                                               | |   |
+  * | | |                                               | |   |
+  * | | |                                               | |   |
+  * | | |                                               | |   |
+  * | | |                                               | |   |
+  * | | |                                               | |   |
+  * | | |                                               | |   |
+  * | | +-----------------------------------------------+ |   |
+  * | | +-----------------------------------------------+ |   |
+  * | | | Summary Line                                  | |   |
+  * | | +-----------------------------------------------+ |   |
+  * | | +-----------------------------------------------+ |   |
+  * | | | kMyMoneyTransactionForm                       | |   |
+  * | | |                                               | |   |
+  * | | |                                               | |   |
+  * | | |                                               | |   |
+  * | | |                                               | |   |
+  * | | |                                               | |   |
+  * | | +-----------------------------------------------+ |   |
+  * | +---------------------------------------------------+   |
+  * +---------------------------------------------------------+
 
   * @endcode
   *
   * The register is provided by kMyMoneyRegisterCheckings. The form
   * is based on a kMyMoneyTransactionForm object. The various parts
   * are created in createRegister(), createSummary() and createForm().
-  * The above diagram shows the standard layout. The buttonLayout is
-  * actually contained as one page in the QWidgetStack m_infoStack.
-  * The widgets therein are created in the createInfoStack() method which
-  * is called by the constructor. A second page exists, which is used by
-  * the reconciliation code.
+  * The above diagram shows the standard layout.
+  *
+  * The transaction form itself has the following layout:
+  *
+  * @code
+  *
+  * +---------------------------------------------------------+
+  * | formLayout                                              |
+  * | +-----------------------------------------------------+ +
+  * | | tabbar                                              | |
+  * | |                                                     | |
+  * | +-----------------------------------------------------+ +
+  * | +-----------------------------------------------------+ +
+  * | | formFrame                                           | |
+  * | | +-------------------------------------------------+ | |
+  * | | | buttons                                         | | |
+  * | | +-------------------------------------------------+ | |
+  * | | +-------------------------------------------------+ | |
+  * | | | kMyMoneyTransactionFormTable                    | | |
+  * | | |                                                 | | |
+  * | | |                                                 | | |
+  * | | |                                                 | | |
+  * | | |                                                 | | |
+  * | | +-------------------------------------------------+ | |
+  * | +-----------------------------------------------------+ +
+  * +---------------------------------------------------------+
+
+  * @endcode
+  *
   *
   * The tabbar on top of the actual form is part of the kMyMoneyTransactionForm
   * widget and shows the possible transaction types. It
@@ -116,7 +140,7 @@ class kMyMoneyTransactionFormTable;
   *
   * fillForm() fills the data provided by the current selected transaction
   * into the read-only form. The layout of the form depends on the type
-  * the selected of transaction.
+  * of the selected of transaction.
   *
   * fillSummary() will be called and should update the summary line.
   */
@@ -125,17 +149,22 @@ class KLedgerViewCheckings : public KLedgerView  {
 
   friend class kMyMoneyTransactionFormTable;
 
-public: 
+public:
   KLedgerViewCheckings(QWidget *parent=0, const char *name=0);
   ~KLedgerViewCheckings();
 
+  /// This has to be included for internal reasons, no API change
+  bool eventFilter(QObject* o, QEvent* e);
+
+  virtual int currentActionTab(void) const;
+
 public slots:
   /**
     * refresh the current view
     */
   virtual void refreshView(void);
 
-  void slotTypeSelected(int transactionType);
+  void slotActionSelected(int transactionType);
 
   /**
     *
@@ -152,24 +181,56 @@ public slots:
     */
   virtual void slotReconciliation(void);
 
+  /**
+    * Called when the amount field has been changed by the user.
+    * m_transaction and m_split will be updated accordingly.
+    *
+    * @param amount const reference to the amount value
+    */
+  virtual void slotAmountChanged(const QString& amount);
+
+  virtual void slotNew(void);
+
 protected:
+  /**
+    * This method updates the summary line with the actual values.
+    */
   void fillSummary(void);
 
+  /**
+    * This method updates the static text areas within the transaction form
+    * according to the currently loaded values in m_transaction and m_split.
+    */
+  void fillFormStatics(void);
+
+  /**
+    * This method updates the variable areas within the transaction form
+    * according to the currently loaded values in m_transaction and m_split.
+    */
   void fillForm(void);
 
+  /**
+    * This method returns the index of the tab that is required for
+    * the transaction @p t and split @p s.
+    *
+    * @param t transaction which should be used
+    * @param s split which should be used
+    */
+  int actionTab(const MyMoneyTransaction& t, const MyMoneySplit& s) const;
+
   void resizeEvent(QResizeEvent*);
 
   /**
-    * This method creates, loads, arranges and shows the widgets required
-    * to edit a transaction. See createEditWidgets(), loadEditWidgets(),
-    * arrangeEditWidgetsInForm() and arrangeEditWidgetsInRegister() for details.
+    * This method resizes the widgets in the transaction form.
     */
-  void showWidgets(void);
+  void resizeForm(void);
 
   /**
     * This destroys and hides the widgets used to edit a transaction.
     */
-  void hideWidgets(void);
+  void destroyWidgets(void);
+
+  void updateTabBar(const MyMoneyTransaction& t, const MyMoneySplit& s, const bool enableAll = false);
 
   /**
     * This method is called to determine the next widget that receives focus
@@ -205,7 +266,13 @@ protected:
     */
   virtual void createMoreMenu(void);
 
-    /**
+  /**
+    * This method creates the context menu that is accessible via the
+    * Account... button in the transaction form.
+    */
+  virtual void createAccountMenu(void);
+
+  /**
     * This method enables or disables widgets who's availability depends
     * on a selected account. These are:
     *
@@ -220,6 +287,16 @@ protected:
     */
   virtual void enableWidgets(const bool enable);
 
+  /**
+    * This method retrieves the transaction type from the GUI elements.
+    * It will be used by transactionType(const MyMoneyTransaction&) in the
+    * case that not enough information is contained in the splits of
+    * the transaction.
+    *
+    * @return KLedgerView::transactionTypeE value of the action
+    */
+  virtual int transactionType(const MyMoneyTransaction& t) const;
+
 protected slots:
   /**
     * Calling this slot opens the account edit dialog for the current
@@ -249,58 +326,42 @@ protected slots:
 
   /**
     * Calling this slot opens the split dialog with the current transaction
-    * loaded.
+    * loaded. If the user interface is currently not editing a transaction,
+    * edit mode will be launched by calling slotStartEdit().
     */
   virtual void slotOpenSplitDialog(void);
 
-  /**
-    * Calling this slot starts editing and opens the split dialog
-    */
-  virtual void slotStartEditSplit(void);
-
   void reloadEditWidgets(const MyMoneyTransaction& t);
 
   void slotPayeeSelected(void);
 
+  void slotTypeSelected(int type);
+
 private:
   /**
     * This method loads the data of the current transaction into the
     * widgets created with createEditWidgets(). If different widgets are
     * required for in-register and in-form editing, all widgets will be filled.
-    * This method also analyses the data of the transaction and determines
-    * the transaction type which is returned in the parameter @p transType.
-    *
-    * @param transType reference to transaction type. The method will set this
-    *                  value upon return to the caller.
-    * @return The return value is passed in the variable referenced by @p transType
     */
-  void loadEditWidgets(int& transType);
+  void loadEditWidgets(void);
 
   /**
-    * This method arranges the widgets required for in-form editing in the
-    * form according to the transaction type passed by @p transType. It destroys
+    * This method arranges the widgets required for in-form editing. It destroys
     * all widgets that have been created specifically for in-register editing.
-    * Depending on the transaction type, the @p focusWidget will be selected.
+    * A pointer to the widget that should receive the focus is returned.
     *
-    * @param focusWidget reference to pointer which will point to the widget
-    *                    that should receive focus when editing starts.
-    * @param transType type of transaction as determined by loadEditWidgets()
-    * @return The return value is passed in the variable referenced by @p focusWidget.
+    * @return pointer to the widget that should receive focus when editing starts.
     */
-  void arrangeEditWidgetsInForm(QWidget*& focusWidget, const int transType);
+  QWidget* arrangeEditWidgetsInForm(void);
 
   /**
-    * This method arranges the widgets required for in-register editing in the
-    * register according to the transaction type passed by @p transType. It destroys
+    * This method arranges the widgets required for in-register editing. It destroys
     * all widgets that have been created specifically for in-form editing.
-    * Depending on the transaction type, the @p focusWidget will be selected.
+    * A pointer to the widget that should receive the focus is returned.
     *
-    * @param focusWidget reference to pointer which will point to the widget
-    *                    that should receive focus when editing starts.
-    * @param transType type of transaction as determined by loadEditWidgets()
-    * @return The return value is passed in the variable referenced by @p focusWidget.
+    * @return pointer to the widget that should receive focus when editing starts.
     */
-  void arrangeEditWidgetsInRegister(QWidget*& focusWidget, const int transType);
+  QWidget* arrangeEditWidgetsInRegister(void);
 
   /**
     * This method is used by the constructor to create the necessary widgets
@@ -314,19 +375,18 @@ private:
     */
   void createSummary(void);
 
-  /**
-    * This method is used by the constructor to create the info stack on
-    * the right of the register widget. The stack widget itself is created
-    * by the base class member of this function.
-    */
-  void createInfoStack(void);
-
   /**
     * This method is used by the constructor to create the transaction form
     * provided by the view.
     */
   void createForm(void);
 
+  /**
+    * This method is used to construct the reconciliation frame shown underneath
+    * the summary line during reconciliation.
+    */
+  void createReconciliationFrame(void);
+
   /**
     * This method updates the respective data shown on the right of the
     * register during reconciliation.
@@ -340,6 +400,24 @@ private:
     */
   void endReconciliation(void);
 
+  /**
+    * This method returns information if the Nr field is to be
+    * displayed and available for the split @p split.
+    *
+    * @param trans the transaction to be checked
+    * @param split the split to be checked
+    * @retval true Nr field is required
+    * @retval false Nr field is not required
+    */
+  const bool showNrField(const MyMoneyTransaction& trans, const MyMoneySplit& split) const;
+
+  /**
+    * If the number field is visible, empty and the current action
+    * is 'Check' and the option to automatically increment the check no
+    * then this method does just that.
+    */
+  void autoIncCheckNumber(void);
+
 private slots:
   /**
     * This method enables and disables the options available for
@@ -355,7 +433,6 @@ private slots:
     */
   void slotConfigureMoreMenu(void);
 
-signals:
 protected:
   QTab* m_tabCheck;
   QTab* m_tabDeposit;
@@ -363,9 +440,6 @@ protected:
   QTab* m_tabWithdrawal;
   QTab* m_tabAtm;
 
-  KPushButton*  m_detailsButton;
-  KPushButton*  m_reconcileButton;
-
   /**
     * This attribute stores the current selected transaction type
     * which is used for new transactions.
@@ -377,9 +451,14 @@ protected:
     * which is located underneath the register. The
     * widget itself is created in createSummary()
     */
-  QLabel          *m_summaryLine;
+  QWidget*        m_summaryLine;
 
-  QHBoxLayout*    m_summaryLayout;
+  /**
+    * This member keeps a pointer to the reconciliation specific information
+    */
+  QFrame*         m_reconciliationFrame;
+
+  short           m_actionIdx[5];
 
 private:
 
@@ -393,9 +472,35 @@ private:
   QLabel*         m_differenceLabel;
 
   QCheckBox*      m_transactionCheckBox;
-  
-  QLabel*         m_lastReconciledLabel;
-
 };
 
+/**
+  * This class implements the summary line widget. It comprises
+  * of two labels and a spacer in between.
+  *
+  * @code
+  *
+  * +----------------------------------------------------+
+  * | Reconcile-Label      <-spacer->      Balance-Label |
+  * +----------------------------------------------------+
+  *
+  * @endcode
+  */
+class KLedgerViewCheckingsSummaryLine : public QFrame
+{
+  Q_OBJECT
+public:
+  KLedgerViewCheckingsSummaryLine(QWidget* parent, const char *name);
+  virtual ~KLedgerViewCheckingsSummaryLine() {};
+
+  void setBalance(const QString& txt);
+  void setReconciliationDate(const QString& txt);
+  void clear(void);
+
+private:
+  QLabel*    m_balance;
+  QLabel*    m_date;
+};
+
+
 #endif
