@@ -854,7 +854,7 @@ bool KMyMoneyView::readFile(const KURL& url)
                 else
                   ungetString(qfile, hdr.data(), 70);
                 QRegExp kmyexp("<!DOCTYPE KMYMONEY-FILE>");
-                QRegExp gncexp("<gnc-v(\\d+)>");
+                QRegExp gncexp("<gnc-v(\\d+)");
                 QCString txt(hdr);
                 if(kmyexp.search(txt) != -1) {
                   pReader = new MyMoneyStorageXML;
@@ -1675,7 +1675,7 @@ void KMyMoneyView::loadDefaultCurrencies(void)
   loadDefaultCurrency(MyMoneySecurity("MTL", i18n("Maltese Lira")), create);
   loadDefaultCurrency(MyMoneySecurity("MRO", i18n("Mauritanian Ouguiya"),    "MRO", 5, 5), create);
   loadDefaultCurrency(MyMoneySecurity("MUR", i18n("Mauritius Rupee")), create);
-  loadDefaultCurrency(MyMoneySecurity("MXP", i18n("Mexican Peso"),           "$"), create);
+  loadDefaultCurrency(MyMoneySecurity("MXN", i18n("Mexican Peso"),           "$"), create);
   loadDefaultCurrency(MyMoneySecurity("MNT", i18n("Mongolian Tugrik"),       QChar(0x20AE)), create);
   loadDefaultCurrency(MyMoneySecurity("MAD", i18n("Moroccan Dirham")), create);
   loadDefaultCurrency(MyMoneySecurity("MZM", i18n("Mozambique Metical")), create);
