@@ -104,10 +104,13 @@ KScheduledView::KScheduledView(QWidget *parent, const char *name )
     this, SLOT(slotSetSelectedItem(QListViewItem*)));
 
   connect(m_calendar, SIGNAL(enterClicked(const MyMoneySchedule&, const QDate&)), this, SLOT(slotBriefEnterClicked(const MyMoneySchedule&, const QDate&)));
+
+  MyMoneyFile::instance()->attach(MyMoneyFile::NotifyClassSchedule, this);
 }
 
 KScheduledView::~KScheduledView()
 {
+  MyMoneyFile::instance()->detach(MyMoneyFile::NotifyClassSchedule, this);
   writeConfig();
 }
 
@@ -227,8 +230,8 @@ void KScheduledView::refresh(bool full, const QCString schedId)
     // using a timeout is the only way, I got the 'ensureTransactionVisible'
     // working when coming from hidden form to visible form. I assume, this
     // has something to do with the delayed update of the display somehow.
-    QTimer::singleShot(10, this, SLOT(slotTimerDone()));
     resize(width(), height()-1);
+    QTimer::singleShot(10, this, SLOT(slotTimerDone()));
     m_qlistviewScheduled->update();
 
     if (m_openBills)
@@ -702,3 +705,15 @@ void KScheduledView::slotSetSelectedItem(QListViewItem* item)
   if(item)
     m_selectedSchedule = schedItem->scheduleId();
 }
+
+void KScheduledView::update(const QCString& /* id */)
+{
+  KScheduledListItem *p = dynamic_cast<KScheduledListItem*>(m_qlistviewScheduled->selectedItem());
+  QCString schedId;
+  if(p)
+    schedId = p->scheduleId();
+  refresh(true, schedId);
+}
+
+
+#include "kscheduledview.moc"
