@@ -51,6 +51,33 @@ kMyMoneyAccountTree::kMyMoneyAccountTree(QWidget* parent, const char* name) :
   connect(this, SIGNAL(dropped(QDropEvent*,QListViewItem*,QListViewItem*)), this, SLOT(slotObjectDropped(QDropEvent*,QListViewItem*,QListViewItem*)));
 }
 
+const KAccountListItem* kMyMoneyAccountTree::findItem(const QCString& id) const
+{
+  // tried to use a  QListViewItemIterator  but that does not fit
+  // with the constness of this method. Arghhh.
+
+  QListViewItem* p = firstChild();
+  while(p) {
+    // item found, check for the id
+    KAccountListItem* item = dynamic_cast<KAccountListItem*>(p);
+    if(item && item->accountID() == id)
+      break;
+
+    // item did not match, search the next one
+    QListViewItem* next = p->firstChild();
+    if(!next) {
+      while((next = p->nextSibling()) == 0) {
+        p = p->parent();
+        if(!p)
+          break;
+      }
+    }
+    p = next;
+  }
+
+  return dynamic_cast<KAccountListItem*>(p);
+}
+
 bool kMyMoneyAccountTree::acceptDrag(QDropEvent* event) const
 {
   bool rc;
@@ -58,47 +85,50 @@ bool kMyMoneyAccountTree::acceptDrag(QDropEvent* event) const
   if(rc = (acceptDrops() && event->source() == viewport())) {
     QPoint vp = contentsToViewport(event->pos());
     QListViewItem *item = itemAt( vp );
-    KAccountListItem* p = dynamic_cast<KAccountListItem*>(item);
+    KAccountListItem* to = dynamic_cast<KAccountListItem*>(item);
     rc = false;
-    if(p) {
+    if(to) {
       QCString id(event->encodedData("text/plain"));
+      const KAccountListItem* from = findItem(id);
       MyMoneyAccount accTo, accFrom;
       try {
-        accTo = MyMoneyFile::instance()->account(p->accountID());
+        accTo = MyMoneyFile::instance()->account(to->accountID());
         accFrom = MyMoneyFile::instance()->account(id);
-        // it does not make sense to reparent an account to oneself
-        // or to reparent it to it's current parent
-        if(accTo.id() != accFrom.id()
-        && accFrom.parentAccountId() != accTo.id()) {
+        if(!to->isChildOf(from) && !MyMoneyFile::instance()->isStandardAccount(id)) {
+          // it does not make sense to reparent an account to oneself
+          // or to reparent it to it's current parent
+          if(accTo.id() != accFrom.id()
+          && accFrom.parentAccountId() != accTo.id()) {
 
-          rc = accTo.accountGroup() == accFrom.accountGroup();
-          if(rc) {
-            if(accTo.accountType() == MyMoneyAccount::Investment
-            && accFrom.accountType() != MyMoneyAccount::Stock)
-              rc = false;
-            else if(accFrom.accountType() == MyMoneyAccount::Stock
-            && accTo.accountType() != MyMoneyAccount::Investment)
-              rc = false;
-          } else {
-            if(accFrom.accountGroup() == MyMoneyAccount::Income
-            && accTo.accountGroup() == MyMoneyAccount::Expense)
-              rc = true;
+            rc = accTo.accountGroup() == accFrom.accountGroup();
+            if(rc) {
+              if(accTo.accountType() == MyMoneyAccount::Investment
+              && accFrom.accountType() != MyMoneyAccount::Stock)
+                rc = false;
+              else if(accFrom.accountType() == MyMoneyAccount::Stock
+              && accTo.accountType() != MyMoneyAccount::Investment)
+                rc = false;
+            } else {
+              if(accFrom.accountGroup() == MyMoneyAccount::Income
+              && accTo.accountGroup() == MyMoneyAccount::Expense)
+                rc = true;
 
-            if(accFrom.accountGroup() == MyMoneyAccount::Expense
-            && accTo.accountGroup() == MyMoneyAccount::Income)
-              rc = true;
+              if(accFrom.accountGroup() == MyMoneyAccount::Expense
+              && accTo.accountGroup() == MyMoneyAccount::Income)
+                rc = true;
 
+            }
           }
         }
 
       } catch(MyMoneyException *e) {
         delete e;
         try {
-          MyMoneyFile::instance()->institution(p->accountID());
+          MyMoneyFile::instance()->institution(to->accountID());
           rc = true;
         } catch(MyMoneyException *e) {
           delete e;
-          rc = p->accountID().isEmpty();
+          rc = to->accountID().isEmpty();
         }
       }
 
