@@ -31,6 +31,7 @@
 
 #include <kdatepicker.h>
 class KPushButton;
+class KPassivePopup;
 
 // ----------------------------------------------------------------------------
 // Project Includes
@@ -66,21 +67,20 @@ public slots:
 signals:
   void dateChanged(const QDate& date);
 
-  /**
-    * This signal is emitted when the user presses RETURN while editing
-    */
-  void signalEnter();
-
-  /**
-    * This signal is emitted when the user presses ESC while editing
-    */
-  void signalEsc();
-
 protected:
-  /** Overriding QWidget::keyPressEvent */
+  /**
+    * - increments/decrements the date upon +/- key input
+    * - increments/decrements the date upon Up/Down key input
+    * - sets the date to current date when the 'T' key is pressed.
+    *   The actual key for this to happen might be overridden through
+    *   an i18n package. The 'T'-key is always possible.
+    */
   void keyPressEvent(QKeyEvent * k);
   void resizeEvent(QResizeEvent*);
 
+  /** To intercept events sent to focusWidget() */
+  bool eventFilter(QObject *o, QEvent *e);
+
 protected slots:
   void slotDateChosen(QDate date);
   void toggleDatePicker();
@@ -97,6 +97,8 @@ private:
   Qt::AlignmentFlags m_qtalignment;
   QVBox *m_dateFrame;
   KPushButton *m_dateButton;
+  KPassivePopup *m_datePopup;
+  int m_focusDatePart;
 };
 
 #endif
