@@ -35,7 +35,8 @@
 kMyMoneyRegister::kMyMoneyRegister(int maxRpt, QWidget *parent, const char *name )
   : QTable(parent, name),
     m_ledgerLens(true),
-    m_maxRpt(maxRpt)
+    m_maxRpt(maxRpt),
+    m_blinkTimer(parent)
 {
   m_cellFont = KMyMoneyUtils::cellFont();
   setFont(m_cellFont);
@@ -43,9 +44,14 @@ kMyMoneyRegister::kMyMoneyRegister(int maxRpt, QWidget *parent, const char *name
   m_currentTransactionIndex = 0;
   m_inlineEditMode = false;
   setSelectionMode(QTable::SingleRow);
-  resize(670,200);
+  // resize(670,200);
   m_editWidgets.clear();
   m_parent = 0;
+  m_errorColor = QColor(255, 0, 0);
+  m_lastErrorColor = m_errorColor;
+
+  m_blinkTimer.start(500);       // setup blink frequency to one hertz
+  connect(&m_blinkTimer, SIGNAL(timeout()), SLOT(slotBlinkInvalid()));
 }
 
 kMyMoneyRegister::~kMyMoneyRegister()
@@ -77,9 +83,10 @@ void kMyMoneyRegister::setTransactionCount(const int r, const bool setTransactio
 
   if(setTransaction) {
     setCurrentTransactionIndex(r);
-  } else if(m_currentTransactionIndex > (r-1))
+  } else if(m_currentTransactionIndex > (r-1)) {
     setCurrentTransactionIndex(r-1);
-  
+  }
+
   // add or remove scrollbars as required
   updateScrollBars();
 }
@@ -97,7 +104,7 @@ void kMyMoneyRegister::readConfig(void)
   m_bgColor = KMyMoneyUtils::backgroundColour();
   m_gridColor = KMyMoneyUtils::gridColour();
   m_importColor = Qt::yellow;
-  
+
   QFont cellFont = KMyMoneyUtils::cellFont();
   m_headerFont = KMyMoneyUtils::headerFont();
   updateHeaders();
@@ -111,8 +118,8 @@ void kMyMoneyRegister::readConfig(void)
     QTable::setNumRows(rows);
   }
 
-  // m_rpt = config->readEntry("RowCount", "1").toInt();
-  config->deleteEntry("RowCount");
+  // m_rpt = config->readEntry("", "1").toInt();
+  config->deleteEntry("");
   if(config->readBoolEntry("ShowRegisterDetailed", false))
     m_rpt = m_maxRpt;
   else
@@ -134,7 +141,7 @@ void kMyMoneyRegister::setTransactionRow(const int row)
     lastRow = (m_currentTransactionIndex * m_rpt) + maxRpt() - 1;
   else
     lastRow = (m_currentTransactionIndex * m_rpt) + m_rpt - 1;
-    
+
   m_transactionIndex = row/m_rpt;
   m_transactionRow = row%m_rpt;
 
@@ -151,7 +158,7 @@ void kMyMoneyRegister::setTransactionRow(const int row)
     qFatal("kMyMoneyRegister::setTransactionRow(): m_parent == 0 !  Use setParent() to set it up");
     exit(0);
   }
-  
+
   m_transaction = m_parent->transaction(m_transactionIndex);
   if(m_transaction != NULL) {
     m_split = m_transaction->splitById(m_transaction->splitId());
@@ -206,7 +213,7 @@ void kMyMoneyRegister::paintCell(QPainter *p, int row, int col, const QRect& r,
 
   // this should have been called by the caller already, but we never know
   setTransactionRow(row);
-  
+
   if(m_transaction != NULL) {
     if(m_transaction->value("Imported").lower() == "true") {
       m_cg.setColor(QColorGroup::Base, m_importColor);
@@ -226,7 +233,7 @@ void kMyMoneyRegister::paintCell(QPainter *p, int row, int col, const QRect& r,
   // p->setPen(m_textColor);
 
   /* new stuff */
-  
+
   const bool lastLine = m_ledgerLens && m_transactionIndex == m_currentTransactionIndex
                          ? m_transactionRow == maxRpt() - 1
                          : m_transactionRow == m_rpt-1;
@@ -254,8 +261,7 @@ void kMyMoneyRegister::paintCell(QPainter *p, int row, int col, const QRect& r,
 
   // QColor textColor(m_textColor);
   // if it's an erronous transaction, set it to error color (which toggles ;-)  )
-  if(m_transaction->splitCount() < 2
-  || m_transaction->splitSum() != 0) {
+  if(!m_transaction->splitSum().isZero()) {
     m_textColor = m_errorColor;
   }
   p->setPen(m_textColor);
@@ -265,7 +271,7 @@ void kMyMoneyRegister::paintCell(QPainter *p, int row, int col, const QRect& r,
     p->drawText(m_textRect, align, " ");
   else
     p->drawText(m_textRect, align, txt);
-  
+
   if(m_transactionIndex == m_currentDateIndex && m_transactionRow == 0) {
     p->setPen(m_gridColor);
     p->drawLine(m_cellRect.x(), 0, m_cellRect.width(), 0);
@@ -293,7 +299,7 @@ void kMyMoneyRegister::contentsMouseReleaseEvent( QMouseEvent* e )
 */
 }
 
-bool kMyMoneyRegister::setCurrentTransactionRow(const int row)
+int kMyMoneyRegister::transactionIndex(const int row) const
 {
   int firstRow,       // first row occupied by current transaction
       lastRow;        // last row occupied by current transaction
@@ -313,7 +319,20 @@ bool kMyMoneyRegister::setCurrentTransactionRow(const int row)
       idx = (row - maxRpt() + m_rpt) / m_rpt;
     }
   }
-  return setCurrentTransactionIndex(idx);
+  return idx;
+}
+
+bool kMyMoneyRegister::differentTransaction(int row) const
+{
+  int idx = transactionIndex(row);
+  if(idx < 0)
+    idx = 0;
+  return (idx != m_currentTransactionIndex);
+}
+
+bool kMyMoneyRegister::setCurrentTransactionRow(const int row)
+{
+  return setCurrentTransactionIndex(transactionIndex(row));
 }
 
 
@@ -358,7 +377,7 @@ void kMyMoneyRegister::ensureTransactionVisible(void)
     next = curr + rpt() + maxRpt() - 1;
   else
     next = curr + rpt()*2 - 1;
-    
+
   int wt = contentsY();           // window top
   int wh = visibleHeight();       // window height
   int lt = prev * rowHeight(0);   // top of line above lens
@@ -387,7 +406,7 @@ bool kMyMoneyRegister::eventFilter(QObject* o, QEvent* e)
     if(m_ledgerLens)
       lines += maxRpt()-1;
     QCString transactionId;
-          
+
     rc = true;
     switch(k->key()) {
       case Qt::Key_Space:
@@ -399,34 +418,30 @@ bool kMyMoneyRegister::eventFilter(QObject* o, QEvent* e)
         break;
 
       case Qt::Key_PageUp:
+        setUpdatesEnabled(false);
         while(lines-- > 0)
           emit signalPreviousTransaction();
+        setUpdatesEnabled(true);
+        ensureTransactionVisible();
+        repaintContents(false);
         break;
-        
+
       case Qt::Key_PageDown:
+        setUpdatesEnabled(false);
         while(lines-- > 0)
           emit signalNextTransaction();
-        break;
+        setUpdatesEnabled(true);
+        ensureTransactionVisible();
+        repaintContents(false);
         break;
 
       case Qt::Key_Home:
         transactionId = m_parent->transaction(0)->id();
         // tricky fall through here
-        
+
       case Qt::Key_End:
         emit signalSelectTransaction(transactionId);
         break;
-        
-        break;
-                        
-      case Qt::Key_Return:
-      case Qt::Key_Enter:
-        emit signalEnter();
-        break;
-
-      case Qt::Key_Escape:
-        emit signalEsc();
-        break;
 
       case Qt::Key_Up:
         emit signalPreviousTransaction();
@@ -568,12 +583,36 @@ void kMyMoneyRegister::updateHeaders(void)
   horizontalHeader()->setFont(m_headerFont);
 }
 
-void kMyMoneyRegister::slotSetErrorColor(const bool state)
+void kMyMoneyRegister::slotBlinkInvalid(void)
 {
-  if(state == false)
-    m_errorColor = m_textColor;
-  else
+  // setup the color invalid transactions will be drawn in
+  if(m_errorColor == m_textColor) {
     m_errorColor = QColor(255, 0, 0);
+  } else {
+    m_errorColor = m_textColor;
+  }
+
+  // now search for invalid transactions in the visible area
+  // and force to repaint them
+
+  if(m_parent && isVisible()) {
+    int c, w = 0;
+    for(c = 0; c < numCols(); ++c) {
+      w += columnWidth(c);
+    }
+    QSize size(w, rowHeight(0));
+
+    for(int r = 0; r < numRows(); ++r) {
+      MyMoneyTransaction* t = m_parent->transaction(transactionIndex(r));
+      if(t && !t->splitSum().isZero()) {
+        QRect cg(QPoint(0,rowPos(r)), size);
+        // following line taken from QTable::repaintCell()
+        QRect pr( QPoint( cg.x() - 2, cg.y() - 2 ),
+                QSize( cg.width() + 4, cg.height() + 4 ) );
+        repaintContents(pr, false);
+      }
+    }
+  }
 }
 
 void kMyMoneyRegister::setCurrentDateIndex(const int idx)
@@ -583,15 +622,23 @@ void kMyMoneyRegister::setCurrentDateIndex(const int idx)
 
 QSize kMyMoneyRegister::sizeHint() const
 {
-  return QSize(670, 200);
+  return minimumSizeHint();
 }
 
 QSize kMyMoneyRegister::minimumSizeHint() const
 {
-  return QSize(500, 200);
+  return QSize(500, 100);
 }
 
 void kMyMoneyRegister::setAction(const QCString& action, const QString& txt)
 {
   m_action[action] = txt;
 }
+
+bool kMyMoneyRegister::focusNextPrevChild(bool next)
+{
+  return m_parent->focusNextPrevChild(next);
+}
+
+
+#include "kmymoneyregister.moc"
